{"%",13,-124,0,*((ulonglong *) at_PERCENT)},
{"%CHANGE",13,-124,0,*((ulonglong *) at_PERCENTCHANGE)},
{"%TOTAL",13,-124,0,*((ulonglong *) at_PERCENTTOTAL)},
{".",13,9,0,*((ulonglong *) at_struct_dot)| 1},
{"ABS",13,-124,0,*((ulonglong *) at_ABS)},
{"ACOS",13,-124,0,*((ulonglong *) at_ACOS)},
{"ACOSH",13,-124,0,*((ulonglong *) at_ACOSH)},
{"ACOT",13,-124,0,*((ulonglong *) at_ACOT)},
{"ACSC",13,-124,0,*((ulonglong *) at_ACSC)},
{"ADDCOL",13,-124,0,*((ulonglong *) at_ADDCOL)| 1},
{"ADDROW",13,-124,0,*((ulonglong *) at_ADDROW)| 1},
{"ALOG",13,-124,0,*((ulonglong *) at_ALOG)},
{"ARC",13,-124,0,*((ulonglong *) at_ARC)},
{"ARG",13,-124,0,*((ulonglong *) at_ARG)},
{"ASEC",13,-124,0,*((ulonglong *) at_ASEC)},
{"ASIN",13,-124,0,*((ulonglong *) at_ASIN)},
{"ASINH",13,-124,0,*((ulonglong *) at_ASINH)},
{"ATAN",13,-124,0,*((ulonglong *) at_ATAN)},
{"ATANH",13,-124,0,*((ulonglong *) at_ATANH)},
{"Airy_Ai",13,9,0,*((ulonglong *) at_Airy_Ai)},
{"Airy_Bi",13,9,0,*((ulonglong *) at_Airy_Bi)},
{"Ans",13,4,0,*((ulonglong *) at_Ans)},
{"Archive",13,77,0,*((ulonglong *) at_Archive)| 1},
{"BINOMIAL",13,9,0,*((ulonglong *) at_BINOMIAL)},
{"BesselI",13,9,0,*((ulonglong *) at_BesselI)},
{"BesselJ",13,9,0,*((ulonglong *) at_BesselJ)},
{"BesselK",13,9,0,*((ulonglong *) at_BesselK)},
{"BesselY",13,9,0,*((ulonglong *) at_BesselY)},
{"Beta",13,9,0,*((ulonglong *) at_Beta)},
{"Bezier",13,9,0,*((ulonglong *) at_Bezier)},
{"BlockDiagonal",13,9,0,*((ulonglong *) at_BlockDiagonal)},
{"CEILING",13,-124,0,*((ulonglong *) at_CEILING)},
{"CHOOSE",13,-124,0,*((ulonglong *) at_CHOOSE)| 1},
{"COLNORM",13,-124,0,*((ulonglong *) at_COLNORM)},
{"COMB",13,-124,0,*((ulonglong *) at_COMB)},
{"CONCAT",13,-124,0,*((ulonglong *) at_CONCAT)},
{"COND",13,-124,0,*((ulonglong *) at_COND)},
{"CONJ",13,-124,0,*((ulonglong *) at_CONJ)},
{"COS",13,-124,0,*((ulonglong *) at_COS)},
{"COSH",13,-124,0,*((ulonglong *) at_COSH)},
{"COT",13,-124,0,*((ulonglong *) at_COT)},
{"CROSS",13,-124,0,*((ulonglong *) at_CROSS)},
{"CSC",13,-124,0,*((ulonglong *) at_CSC)},
{"Celsius2Fahrenheit",13,9,0,*((ulonglong *) at_Celsius2Fahrenheit)},
{"Ci",13,9,0,*((ulonglong *) at_Ci)},
{"Ci0",13,9,0,*((ulonglong *) at_Ci0)},
{"Circle",13,77,0,*((ulonglong *) at_Circle)},
{"ClrDraw",13,8,0,*((ulonglong *) at_ClrDraw)},
{"ClrGraph",13,8,0,*((ulonglong *) at_ClrGraph)},
{"ClrIO",13,8,0,*((ulonglong *) at_ClrIO)},
{"CopyVar",13,77,0,*((ulonglong *) at_CopyVar)| 1},
{"CyclePic",13,77,0,*((ulonglong *) at_CyclePic)},
{"DEGXRAD",13,-124,0,*((ulonglong *) at_DEGXRAD)},
{"DELCOL",13,-124,0,*((ulonglong *) at_DELCOL)| 1},
{"DELROW",13,-124,0,*((ulonglong *) at_DELROW)| 1},
{"DET",13,-124,0,*((ulonglong *) at_DET)},
{"DISP",13,-124,0,*((ulonglong *) at_DISP)| 1},
{"DOT",13,-124,0,*((ulonglong *) at_DOT)},
{"DROP",13,85,0,*((ulonglong *) at_DROP)},
{"DUP",13,85,0,*((ulonglong *) at_DUP)},
{"DelFold",13,77,0,*((ulonglong *) at_DelFold)| 1},
{"DelVar",13,77,0,*((ulonglong *) at_DelVar)| 1},
{"Det",13,9,0,*((ulonglong *) at_Det)},
{"Dirac",13,9,0,*((ulonglong *) at_Dirac)},
{"DispG",13,8,0,*((ulonglong *) at_DispG)},
{"DispHome",13,8,0,*((ulonglong *) at_DispHome)},
{"DrawFunc",13,77,0,*((ulonglong *) at_DrawFunc)},
{"DrawInv",13,77,0,*((ulonglong *) at_DrawInv)},
{"DrawParm",13,77,0,*((ulonglong *) at_DrawParm)},
{"DrawPol",13,77,0,*((ulonglong *) at_DrawPol)},
{"DrawSlp",13,77,0,*((ulonglong *) at_DrawSlp)},
{"DrwCtour",13,77,0,*((ulonglong *) at_DrwCtour)},
{"EDITMAT",13,-124,0,*((ulonglong *) at_EDITMAT)| 1},
{"EIGENVAL",13,-124,0,*((ulonglong *) at_EIGENVAL)},
{"EIGENVV",13,-124,0,*((ulonglong *) at_EIGENVV)},
{"EXP",13,-124,0,*((ulonglong *) at_EXP)},
{"EXPM1",13,-124,0,*((ulonglong *) at_EXPM1)},
{"EXPORT",13,77,0,*((ulonglong *) at_EXPORT)| 1},
{"Ei",13,9,0,*((ulonglong *) at_Ei)},
{"Ei0",13,9,0,*((ulonglong *) at_Ei0)},
{"Ei_f",13,9,0,*((ulonglong *) at_Ei_f)},
{"Eta",13,9,0,*((ulonglong *) at_Eta)},
{"Exec",13,77,0,*((ulonglong *) at_Exec)},
{"FLOOR",13,-124,0,*((ulonglong *) at_FLOOR)},
{"FNROOT",13,-124,0,*((ulonglong *) at_FNROOT)| 1},
{"FP",13,-124,0,*((ulonglong *) at_FP)},
{"Factor",13,9,0,*((ulonglong *) at_Factor)},
{"Fahrenheit2Celsius",13,9,0,*((ulonglong *) at_Fahrenheit2Celsius)},
{"Fill",13,77,0,*((ulonglong *) at_Fill)| 1},
{"GETKEY",13,-124,0,*((ulonglong *) at_GETKEY)},
{"GF",13,9,0,*((ulonglong *) at_GF)},
{"Gamma",13,9,0,*((ulonglong *) at_Gamma)},
{"Gcd",13,9,0,*((ulonglong *) at_Gcd)},
{"Gcdex",13,9,0,*((ulonglong *) at_Gcdex)},
{"Get",13,77,0,*((ulonglong *) at_Get)| 1},
{"GetCalc",13,77,0,*((ulonglong *) at_GetCalc)| 1},
{"GetFold",13,8,0,*((ulonglong *) at_GetFold)},
{"Graph",13,77,0,*((ulonglong *) at_Graph)},
{"HMSX",13,-124,0,*((ulonglong *) at_HMSX)},
{"Heaviside",13,9,0,*((ulonglong *) at_Heaviside)},
{"IDENMAT",13,-124,0,*((ulonglong *) at_IDENMAT)},
{"IFTE",13,85,0,*((ulonglong *) at_IFTE)},
{"IM",13,-124,0,*((ulonglong *) at_IM)},
{"INPUT",13,-124,0,*((ulonglong *) at_INPUT)| 1},
{"INTERSECT",13,-124,0,*((ulonglong *) at_INTERSECT)},
{"INVERSE",13,-124,0,*((ulonglong *) at_INVERSE)},
{"IP",13,-124,0,*((ulonglong *) at_IP)},
{"ISOLATE",13,-124,0,*((ulonglong *) at_ISOLATE)| 1},
{"ITERATE",13,-124,0,*((ulonglong *) at_ITERATE)| 1},
{"Input",13,77,0,*((ulonglong *) at_Input)| 1},
{"InputStr",13,77,0,*((ulonglong *) at_InputStr)| 1},
{"Int",13,9,0,*((ulonglong *) at_Int)},
{"Inverse",13,9,0,*((ulonglong *) at_Inverse)},
{"JordanBlock",13,9,0,*((ulonglong *) at_JordanBlock)},
{"Kronecker",13,9,0,*((ulonglong *) at_Kronecker)},
{"LINE",13,-124,0,*((ulonglong *) at_LINE)},
{"LINEAR?",13,-124,0,*((ulonglong *) at_IS_LINEAR)| 1},
{"LN",13,-124,0,*((ulonglong *) at_LN)},
{"LNP1",13,-124,0,*((ulonglong *) at_LNP1)},
{"LOG",13,-124,0,*((ulonglong *) at_LOG)},
{"LQ",13,-124,0,*((ulonglong *) at_LQ)},
{"LSQ",13,-124,0,*((ulonglong *) at_LSQ)},
{"LU",13,9,0,*((ulonglong *) at_LU)| 1},
{"Li",13,9,0,*((ulonglong *) at_Li)},
{"Line",13,77,0,*((ulonglong *) at_Line)},
{"LineHorz",13,77,0,*((ulonglong *) at_LineHorz)},
{"LineTan",13,77,0,*((ulonglong *) at_LineTan)},
{"LineVert",13,77,0,*((ulonglong *) at_LineVert)},
{"MAKELIST",13,-124,0,*((ulonglong *) at_MAKELIST)| 1},
{"MAKEMAT",13,-124,0,*((ulonglong *) at_MAKEMAT)| 1},
{"MANT",13,-124,0,*((ulonglong *) at_MANT)},
{"MAX",13,-124,0,*((ulonglong *) at_MAX)},
{"MAXREAL",13,2,0,*((ulonglong *) at_MAXREAL)},
{"MIN",13,-124,0,*((ulonglong *) at_MIN)},
{"MINREAL",13,2,0,*((ulonglong *) at_MINREAL)},
{"MINUS",13,-124,0,*((ulonglong *) at_MINUS)},
{"MOD",13,21,0,*((ulonglong *) at_MOD)},
{"MSGBOX",13,-124,0,*((ulonglong *) at_MSGBOX)},
{"NOP",13,85,0,*((ulonglong *) at_NOP)},
{"NORMALD",13,9,0,*((ulonglong *) at_NORMALD)},
{"NTHROOT",13,23,0,*((ulonglong *) at_NTHROOT)},
{"NewFold",13,77,0,*((ulonglong *) at_NewFold)| 1},
{"NewPic",13,77,0,*((ulonglong *) at_NewPic)},
{"Nop",13,9,0,*((ulonglong *) at_Nop)},
{"Nullspace",13,9,0,*((ulonglong *) at_Nullspace)},
{"OVER",13,85,0,*((ulonglong *) at_OVER)},
{"Output",13,77,0,*((ulonglong *) at_Output)},
{"Ox_2d_unit_vector",13,9,0,*((ulonglong *) at_Ox_2d_unit_vector)},
{"Ox_3d_unit_vector",13,9,0,*((ulonglong *) at_Ox_3d_unit_vector)},
{"Oy_2d_unit_vector",13,9,0,*((ulonglong *) at_Oy_2d_unit_vector)},
{"Oy_3d_unit_vector",13,9,0,*((ulonglong *) at_Oy_3d_unit_vector)},
{"Oz_3d_unit_vector",13,9,0,*((ulonglong *) at_Oz_3d_unit_vector)},
{"PERM",13,-124,0,*((ulonglong *) at_PERM)},
{"PICK",13,85,0,*((ulonglong *) at_PICK)},
{"PIECEWISE",13,9,0,*((ulonglong *) at_PIECEWISE)| 1},
{"PIXOFF",13,-124,0,*((ulonglong *) at_PIXOFF)},
{"PIXON",13,-124,0,*((ulonglong *) at_PIXON)},
{"POISSON",13,9,0,*((ulonglong *) at_POISSON)},
{"POLYCOEF",13,9,0,*((ulonglong *) at_POLYCOEF)| 1},
{"POLYEVAL",13,-124,0,*((ulonglong *) at_POLYEVAL)},
{"POLYFORM",13,-124,0,*((ulonglong *) at_POLYFORM)| 1},
{"POLYROOT",13,-124,0,*((ulonglong *) at_POLYROOT)| 1},
{"POS",13,-124,0,*((ulonglong *) at_POS)},
{"PRINT",13,-124,0,*((ulonglong *) at_PRINT)| 1},
{"Pause",13,77,0,*((ulonglong *) at_Pause)},
{"Phi",13,9,0,*((ulonglong *) at_Phi)},
{"Pictsize",13,9,0,*((ulonglong *) at_Pictsize)},
{"PopUp",13,77,0,*((ulonglong *) at_PopUp)| 1},
{"Prompt",13,77,0,*((ulonglong *) at_Prompt)| 1},
{"Psi",13,9,0,*((ulonglong *) at_Psi)},
{"Psi_minus_ln",13,9,0,*((ulonglong *) at_Psi_minus_ln)},
{"PtOff",13,77,0,*((ulonglong *) at_PtOff)},
{"PtOn",13,77,0,*((ulonglong *) at_PtOn)},
{"PtText",13,77,0,*((ulonglong *) at_PtText)},
{"PxlOff",13,77,0,*((ulonglong *) at_PxlOff)},
{"PxlOn",13,77,0,*((ulonglong *) at_PxlOn)},
{"QR",13,9,0,*((ulonglong *) at_QR)| 1},
{"QUAD",13,-124,0,*((ulonglong *) at_QUAD)| 1},
{"QUOTE",13,-124,0,*((ulonglong *) at_QUOTE)| 1},
{"Quo",13,9,0,*((ulonglong *) at_Quo)},
{"RADXDEG",13,-124,0,*((ulonglong *) at_RADXDEG)},
{"RANDMAT",13,-124,0,*((ulonglong *) at_RANDMAT)| 1},
{"RANDOM",13,77,0,*((ulonglong *) at_RANDOM)},
{"RANDSEED",13,77,0,*((ulonglong *) at_RANDSEED)},
{"RANK",13,-124,0,*((ulonglong *) at_RANK)},
{"RCL",13,85,0,*((ulonglong *) at_RCL)},
{"RE",13,-124,0,*((ulonglong *) at_RE)},
{"RECT",13,-124,0,*((ulonglong *) at_RECT)},
{"RECURSE",13,-124,0,*((ulonglong *) at_RECURSE)| 1},
{"REDIM",13,-124,0,*((ulonglong *) at_REDIM)| 1},
{"REPLACE",13,-124,0,*((ulonglong *) at_REPLACE)| 1},
{"REVERSE",13,-124,0,*((ulonglong *) at_REVERSE)},
{"ROUND",13,-124,0,*((ulonglong *) at_ROUND)},
{"ROWNORM",13,-124,0,*((ulonglong *) at_ROWNORM)},
{"RPN_CASE",13,85,0,*((ulonglong *) at_RPN_CASE)},
{"RPN_FOR",13,85,0,*((ulonglong *) at_RPN_FOR)},
{"RPN_LOCAL",13,85,0,*((ulonglong *) at_RPN_LOCAL)},
{"RPN_WHILE",13,85,0,*((ulonglong *) at_RPN_WHILE)},
{"RREF",13,-124,0,*((ulonglong *) at_RREF)},
{"RandSeed",13,77,0,*((ulonglong *) at_RandSeed)},
{"Rank",13,9,0,*((ulonglong *) at_Rank)},
{"RclPic",13,77,0,*((ulonglong *) at_RclPic)| 1},
{"Rem",13,9,0,*((ulonglong *) at_Rem)},
{"Resultant",13,9,0,*((ulonglong *) at_Resultant)},
{"RplcPic",13,77,0,*((ulonglong *) at_RplcPic)| 1},
{"Rref",13,9,0,*((ulonglong *) at_Rref)},
{"SCALE",13,-124,0,*((ulonglong *) at_SCALE)| 1},
{"SCALEADD",13,-124,0,*((ulonglong *) at_SCALEADD)| 1},
{"SCHUR",13,-124,0,*((ulonglong *) at_SCHUR)},
{"SEC",13,-124,0,*((ulonglong *) at_SEC)},
{"SIGN",13,-124,0,*((ulonglong *) at_SIGN)},
{"SIN",13,-124,0,*((ulonglong *) at_SIN)},
{"SINH",13,-124,0,*((ulonglong *) at_SINH)},
{"SIZE",13,-124,0,*((ulonglong *) at_SIZE)},
{"SORT",13,-124,0,*((ulonglong *) at_SORT)},
{"SPECNORM",13,-124,0,*((ulonglong *) at_SPECNORM)},
{"SPECRAD",13,-124,0,*((ulonglong *) at_SPECRAD)},
{"SUB",13,-124,0,*((ulonglong *) at_SUB)| 1},
{"SVD",13,-124,0,*((ulonglong *) at_SVD)},
{"SVL",13,-124,0,*((ulonglong *) at_SVL)},
{"SWAP",13,85,0,*((ulonglong *) at_SWAP)},
{"SWAPCOL",13,-124,0,*((ulonglong *) at_SWAPCOL)| 1},
{"SWAPROW",13,-124,0,*((ulonglong *) at_SWAPROW)| 1},
{"SetFold",13,77,0,*((ulonglong *) at_SetFold)| 1},
{"Si",13,9,0,*((ulonglong *) at_Si)},
{"SiCi_f",13,9,0,*((ulonglong *) at_SiCi_f)},
{"SiCi_g",13,9,0,*((ulonglong *) at_SiCi_g)},
{"SortA",13,77,0,*((ulonglong *) at_SortA)| 1},
{"SortD",13,77,0,*((ulonglong *) at_SortD)| 1},
{"StoPic",13,77,0,*((ulonglong *) at_StoPic)| 1},
{"Store",13,9,0,*((ulonglong *) at_Store)| 1},
{"Sum",13,9,0,*((ulonglong *) at_Sum)| 1},
{"TAN",13,-124,0,*((ulonglong *) at_TAN)},
{"TANH",13,-124,0,*((ulonglong *) at_TANH)},
{"TAYLOR",13,-124,0,*((ulonglong *) at_TAYLOR)| 1},
{"TRACE",13,-124,0,*((ulonglong *) at_TRACE)},
{"TRN",13,-124,0,*((ulonglong *) at_TRN)},
{"TRUNCATE",13,-124,0,*((ulonglong *) at_TRUNCATE)},
{"TeX",13,9,0,*((ulonglong *) at_TeX)},
{"UNION",13,-124,0,*((ulonglong *) at_UNION)},
{"UTPC",13,9,0,*((ulonglong *) at_UTPC)},
{"UTPF",13,9,0,*((ulonglong *) at_UTPF)},
{"UTPN",13,9,0,*((ulonglong *) at_UTPN)},
{"UTPT",13,9,0,*((ulonglong *) at_UTPT)},
{"Unarchiv",13,77,0,*((ulonglong *) at_Unarchiv)| 1},
{"VAS",13,9,0,*((ulonglong *) at_VAS)},
{"VAS_positive",13,9,0,*((ulonglong *) at_VAS_positive)},
{"VIEWS",13,77,0,*((ulonglong *) at_VIEWS)| 1},
{"WAIT",13,-124,0,*((ulonglong *) at_WAIT)},
{"XHMS",13,-124,0,*((ulonglong *) at_XHMS)},
{"XPON",13,-124,0,*((ulonglong *) at_XPON)},
{"Zeta",13,9,0,*((ulonglong *) at_Zeta)},
{"ZoomRcl",13,77,0,*((ulonglong *) at_ZoomRcl)},
{"ZoomSto",13,77,0,*((ulonglong *) at_ZoomSto)},
{"a2q",13,9,0,*((ulonglong *) at_a2q)},
{"abcuv",13,9,0,*((ulonglong *) at_abcuv)},
{"about",13,9,0,*((ulonglong *) at_about)},
{"abs",13,9,0,*((ulonglong *) at_abs)},
{"abscissa",13,9,0,*((ulonglong *) at_abscissa)},
{"accumulate_head_tail",13,9,0,*((ulonglong *) at_accumulate_head_tail)},
{"acos",13,9,0,*((ulonglong *) at_acos)},
{"acos2asin",13,9,0,*((ulonglong *) at_acos2asin)},
{"acos2atan",13,9,0,*((ulonglong *) at_acos2atan)},
{"acosh",13,9,0,*((ulonglong *) at_acosh)},
{"acot",13,9,0,*((ulonglong *) at_acot)},
{"acoth",13,9,0,*((ulonglong *) at_acoth)},
{"acsc",13,9,0,*((ulonglong *) at_acsc)},
{"add",13,9,0,*((ulonglong *) at_add)| 1},
{"add_autosimplify",13,9,0,*((ulonglong *) at_add_autosimplify)| 1},
{"add_language",13,9,0,*((ulonglong *) at_add_language)},
{"additionally",13,9,0,*((ulonglong *) at_additionally)| 1},
{"adjoint_matrix",13,9,0,*((ulonglong *) at_adjoint_matrix)},
{"affix",13,9,0,*((ulonglong *) at_affix)},
{"alg",13,9,0,*((ulonglong *) at_alg)},
{"algsubs",13,9,0,*((ulonglong *) at_algsubs)},
{"algvar",13,9,0,*((ulonglong *) at_algvar)},
{"alog10",13,9,0,*((ulonglong *) at_alog10)},
{"alors",13,49,0,*((ulonglong *) at_alors)| 1},
{"altitude",13,9,0,*((ulonglong *) at_altitude)},
{"and",13,33,0,*((ulonglong *) at_and)| 1},
{"angle",13,9,0,*((ulonglong *) at_angle)},
{"angleat",13,9,0,*((ulonglong *) at_angleat)| 1},
{"angleatraw",13,9,0,*((ulonglong *) at_angleatraw)},
{"animate",13,9,0,*((ulonglong *) at_animate)},
{"animate3d",13,9,0,*((ulonglong *) at_animate3d)},
{"animation",13,9,0,*((ulonglong *) at_animation)},
{"ans",13,9,0,*((ulonglong *) at_ans)},
{"append",13,9,0,*((ulonglong *) at_append)},
{"apply",13,9,0,*((ulonglong *) at_apply)},
{"approx",13,9,0,*((ulonglong *) at_approx)},
{"arc",13,9,0,*((ulonglong *) at_arc)| 1},
{"arcLen",13,9,0,*((ulonglong *) at_arcLen)},
{"archive",13,9,0,*((ulonglong *) at_archive)},
{"arclen",13,9,0,*((ulonglong *) at_arclen)},
{"area",13,9,0,*((ulonglong *) at_area)},
{"areaat",13,9,0,*((ulonglong *) at_areaat)| 1},
{"areaatraw",13,9,0,*((ulonglong *) at_areaatraw)},
{"areaplot",13,9,0,*((ulonglong *) at_areaplot)},
{"arg",13,9,0,*((ulonglong *) at_arg)},
{"array",13,9,0,*((ulonglong *) at_array)},
{"array_sto",13,9,0,*((ulonglong *) at_array_sto)| 1},
{"as_function_of",13,9,0,*((ulonglong *) at_as_function_of)| 1},
{"asc",13,9,0,*((ulonglong *) at_asc)},
{"asec",13,9,0,*((ulonglong *) at_asec)},
{"asin",13,9,0,*((ulonglong *) at_asin)},
{"asin2acos",13,9,0,*((ulonglong *) at_asin2acos)},
{"asin2atan",13,9,0,*((ulonglong *) at_asin2atan)},
{"asinh",13,9,0,*((ulonglong *) at_asinh)},
{"assert",13,77,0,*((ulonglong *) at_assert)| 1},
{"assign",13,9,0,*((ulonglong *) at_assign)},
{"assume",13,9,0,*((ulonglong *) at_assume)| 1},
{"atan",13,9,0,*((ulonglong *) at_atan)},
{"atan2",13,9,0,*((ulonglong *) at_atan2)},
{"atan2acos",13,9,0,*((ulonglong *) at_atan2acos)},
{"atan2asin",13,9,0,*((ulonglong *) at_atan2asin)},
{"atanh",13,9,0,*((ulonglong *) at_atanh)},
{"atrig2ln",13,9,0,*((ulonglong *) at_atrig2ln)},
{"augment",13,9,0,*((ulonglong *) at_augment)},
{"auto_correlation",13,9,0,*((ulonglong *) at_auto_correlation)},
{"autosimplify",13,9,0,*((ulonglong *) at_autosimplify)},
{"avance",13,126,0,*((ulonglong *) at_avance)},
{"avgRC",13,9,0,*((ulonglong *) at_avgRC)},
{"back",13,9,0,*((ulonglong *) at_back)},
{"background",13,9,0,*((ulonglong *) at_background)| 1},
{"backward",13,9,0,*((ulonglong *) at_backward)},
{"baisse_crayon",13,126,0,*((ulonglong *) at_baisse_crayon)},
{"bar_plot",13,9,0,*((ulonglong *) at_bar_plot)},
{"barplot",13,9,0,*((ulonglong *) at_barplot)},
{"bartlett_hann_window",13,9,0,*((ulonglong *) at_bartlett_hann_window)},
{"barycenter",13,9,0,*((ulonglong *) at_barycenter)},
{"basis",13,9,0,*((ulonglong *) at_basis)},
{"batons",13,9,0,*((ulonglong *) at_batons)},
{"bernoulli",13,9,0,*((ulonglong *) at_bernoulli)},
{"besselI",13,9,0,*((ulonglong *) at_besselI)},
{"besselJ",13,9,0,*((ulonglong *) at_besselJ)},
{"besselK",13,9,0,*((ulonglong *) at_besselK)},
{"besselY",13,9,0,*((ulonglong *) at_besselY)},
{"betad",13,9,0,*((ulonglong *) at_betad)},
{"betad_cdf",13,9,0,*((ulonglong *) at_betad_cdf)},
{"betad_icdf",13,9,0,*((ulonglong *) at_betad_icdf)},
{"bezier",13,9,0,*((ulonglong *) at_bezier)},
{"bezout_entiers",13,9,0,*((ulonglong *) at_bezout_entiers)},
{"binomial",13,9,0,*((ulonglong *) at_binomial)},
{"binomial_cdf",13,9,0,*((ulonglong *) at_binomial_cdf)},
{"binomial_icdf",13,9,0,*((ulonglong *) at_binomial_icdf)},
{"binprint",13,9,0,*((ulonglong *) at_binprint)},
{"bisector",13,9,0,*((ulonglong *) at_bisector)},
{"bitand",13,9,0,*((ulonglong *) at_bitand)},
{"bitmap",13,9,0,*((ulonglong *) at_bitmap)},
{"bitor",13,9,0,*((ulonglong *) at_bitor)},
{"bitxor",13,9,0,*((ulonglong *) at_bitxor)},
{"black",13,2,0,*((ulonglong *) at_black)},
{"blackman_harris_window",13,9,0,*((ulonglong *) at_blackman_harris_window)},
{"blackman_window",13,9,0,*((ulonglong *) at_blackman_window)},
{"blockmatrix",13,9,0,*((ulonglong *) at_blockmatrix)},
{"blockmatrix_mult_size",13,9,0,*((ulonglong *) at_blockmatrix_mult_size)},
{"blue",13,2,0,*((ulonglong *) at_blue)},
{"bohman_window",13,9,0,*((ulonglong *) at_bohman_window)},
{"border",13,9,0,*((ulonglong *) at_border)},
{"bounded_function",13,9,0,*((ulonglong *) at_bounded_function)},
{"boxwhisker",13,9,0,*((ulonglong *) at_boxwhisker)},
{"break",13,68,0,*((ulonglong *) at_break)},
{"breakpoint",13,9,0,*((ulonglong *) at_breakpoint)| 1},
{"c1oc2",13,9,0,*((ulonglong *) at_c1oc2)},
{"c1op2",13,9,0,*((ulonglong *) at_c1op2)},
{"cFactor",13,9,0,*((ulonglong *) at_cFactor)},
{"cSolve",13,9,0,*((ulonglong *) at_cSolve)| 1},
{"cZeros",13,9,0,*((ulonglong *) at_cZeros)| 1},
{"cache_tortue",13,126,0,*((ulonglong *) at_cache_tortue)},
{"calc_mode",13,9,0,*((ulonglong *) at_calc_mode)},
{"camembert",13,9,0,*((ulonglong *) at_camembert)},
{"canonical_form",13,9,0,*((ulonglong *) at_canonical_form)},
{"cap",13,126,0,*((ulonglong *) at_cap)},
{"cas_setup",13,9,0,*((ulonglong *) at_cas_setup)},
{"caseval",13,9,0,*((ulonglong *) at_caseval)| 1},
{"cat",13,9,0,*((ulonglong *) at_cat)},
{"cauchy",13,9,0,*((ulonglong *) at_cauchy)},
{"cauchy_cdf",13,9,0,*((ulonglong *) at_cauchy_cdf)},
{"cauchy_icdf",13,9,0,*((ulonglong *) at_cauchy_icdf)},
{"cauchyd",13,9,0,*((ulonglong *) at_cauchyd)},
{"cauchyd_cdf",13,9,0,*((ulonglong *) at_cauchyd_cdf)},
{"cauchyd_icdf",13,9,0,*((ulonglong *) at_cauchyd_icdf)},
{"cd",13,9,0,*((ulonglong *) at_cd)},
{"cdf",13,9,0,*((ulonglong *) at_cdf)},
{"cdfplot",13,9,0,*((ulonglong *) at_cdfplot)},
{"ceil",13,9,0,*((ulonglong *) at_ceil)},
{"ceiling",13,9,0,*((ulonglong *) at_ceiling)},
{"cell",13,9,0,*((ulonglong *) at_cell)},
{"center",13,9,0,*((ulonglong *) at_center)},
{"center2interval",13,9,0,*((ulonglong *) at_center2interval)},
{"centered_cube",13,9,0,*((ulonglong *) at_centered_cube)},
{"centered_tetrahedron",13,9,0,*((ulonglong *) at_centered_tetrahedron)},
{"cfactor",13,9,0,*((ulonglong *) at_cfactor)},
{"cfsolve",13,9,0,*((ulonglong *) at_cfsolve)| 1},
{"changebase",13,9,0,*((ulonglong *) at_changebase)},
{"char",13,9,0,*((ulonglong *) at_char)},
{"charpoly",13,9,0,*((ulonglong *) at_charpoly)},
{"chinrem",13,9,0,*((ulonglong *) at_chinrem)},
{"chisquare",13,9,0,*((ulonglong *) at_chisquare)},
{"chisquare_cdf",13,9,0,*((ulonglong *) at_chisquare_cdf)},
{"chisquare_icdf",13,9,0,*((ulonglong *) at_chisquare_icdf)},
{"chisquared",13,9,0,*((ulonglong *) at_chisquared)},
{"chisquared_cdf",13,9,0,*((ulonglong *) at_chisquared_cdf)},
{"chisquared_icdf",13,9,0,*((ulonglong *) at_chisquared_icdf)},
{"chisquaret",13,9,0,*((ulonglong *) at_chisquaret)},
{"choice",13,9,0,*((ulonglong *) at_choice)},
{"cholesky",13,9,0,*((ulonglong *) at_cholesky)},
{"choosebox",13,9,0,*((ulonglong *) at_choosebox)| 1},
{"chr",13,9,0,*((ulonglong *) at_chr)},
{"chrem",13,9,0,*((ulonglong *) at_chrem)},
{"circle",13,9,0,*((ulonglong *) at_circle)| 1},
{"circumcircle",13,9,0,*((ulonglong *) at_circumcircle)},
{"classes",13,9,0,*((ulonglong *) at_classes)},
{"clear",13,9,0,*((ulonglong *) at_clear)| 1},
{"clearscreen",13,126,0,*((ulonglong *) at_clearscreen)},
{"click",13,9,0,*((ulonglong *) at_click)| 1},
{"close",13,9,0,*((ulonglong *) at_close)| 1},
{"coeff",13,9,0,*((ulonglong *) at_coeff)},
{"coeffs",13,9,0,*((ulonglong *) at_coeffs)},
{"col",13,9,0,*((ulonglong *) at_col)},
{"colDim",13,9,0,*((ulonglong *) at_colDim)},
{"colNorm",13,9,0,*((ulonglong *) at_colNorm)},
{"colSwap",13,9,0,*((ulonglong *) at_colSwap)},
{"coldim",13,9,0,*((ulonglong *) at_coldim)},
{"collect",13,9,0,*((ulonglong *) at_collect)},
{"colnorm",13,9,0,*((ulonglong *) at_colnorm)},
{"color",13,9,0,*((ulonglong *) at_color)},
{"colspace",13,9,0,*((ulonglong *) at_colspace)},
{"colswap",13,9,0,*((ulonglong *) at_colswap)},
{"comDenom",13,9,0,*((ulonglong *) at_comDenom)},
{"comb",13,9,0,*((ulonglong *) at_comb)},
{"combine",13,9,0,*((ulonglong *) at_combine)},
{"comment",13,9,0,*((ulonglong *) at_comment)},
{"common_perpendicular",13,9,0,*((ulonglong *) at_common_perpendicular)},
{"companion",13,9,0,*((ulonglong *) at_companion)},
{"compare",13,9,0,*((ulonglong *) at_compare)},
{"complex",13,9,0,*((ulonglong *) at_complex)},
{"complexroot",13,9,0,*((ulonglong *) at_complexroot)},
{"concat",13,9,0,*((ulonglong *) at_concat)},
{"cond",13,9,0,*((ulonglong *) at_cond)},
{"cone",13,9,0,*((ulonglong *) at_cone)},
{"conic",13,9,0,*((ulonglong *) at_conic)},
{"conj",13,9,0,*((ulonglong *) at_conj)},
{"conjugate_gradient",13,9,0,*((ulonglong *) at_conjugate_gradient)},
{"cont",13,9,0,*((ulonglong *) at_cont)| 1},
{"contains",13,9,0,*((ulonglong *) at_contains)},
{"content",13,9,0,*((ulonglong *) at_content)},
{"contourplot",13,9,0,*((ulonglong *) at_contourplot)| 1},
{"convert",13,9,0,*((ulonglong *) at_convert)},
{"convert3d",13,9,0,*((ulonglong *) at_convert3d)},
{"convertir",13,9,0,*((ulonglong *) at_convertir)},
{"convexhull",13,9,0,*((ulonglong *) at_convexhull)},
{"convolution",13,9,0,*((ulonglong *) at_convolution)},
{"coordinates",13,9,0,*((ulonglong *) at_coordinates)},
{"copy",13,9,0,*((ulonglong *) at_copy)},
{"correlation",13,9,0,*((ulonglong *) at_correlation)},
{"cos",13,9,0,*((ulonglong *) at_cos)},
{"cos2sintan",13,9,0,*((ulonglong *) at_cos2sintan)},
{"cosh",13,9,0,*((ulonglong *) at_cosh)},
{"cosine_window",13,9,0,*((ulonglong *) at_cosine_window)},
{"cot",13,9,0,*((ulonglong *) at_cot)},
{"cote",13,9,0,*((ulonglong *) at_cote)},
{"coth",13,9,0,*((ulonglong *) at_coth)},
{"count",13,9,0,*((ulonglong *) at_count)},
{"count_eq",13,9,0,*((ulonglong *) at_count_eq)},
{"count_inf",13,9,0,*((ulonglong *) at_count_inf)},
{"count_sup",13,9,0,*((ulonglong *) at_count_sup)},
{"courbe_parametrique",13,9,0,*((ulonglong *) at_courbe_parametrique)| 1},
{"courbe_polaire",13,9,0,*((ulonglong *) at_courbe_polaire)| 1},
{"covariance",13,9,0,*((ulonglong *) at_covariance)},
{"covariance_correlation",13,9,0,*((ulonglong *) at_covariance_correlation)},
{"cpartfrac",13,9,0,*((ulonglong *) at_cpartfrac)},
{"cpp",13,9,0,*((ulonglong *) at_cpp)| 1},
{"cprint",13,9,0,*((ulonglong *) at_cprint)| 1},
{"crationalroot",13,9,0,*((ulonglong *) at_crationalroot)},
{"crayon",13,126,0,*((ulonglong *) at_crayon)},
{"critical",13,9,0,*((ulonglong *) at_critical)| 1},
{"cross",13,9,0,*((ulonglong *) at_cross)},
{"crossP",13,9,0,*((ulonglong *) at_crossP)},
{"cross_correlation",13,9,0,*((ulonglong *) at_cross_correlation)},
{"cross_ratio",13,9,0,*((ulonglong *) at_cross_ratio)},
{"crossproduct",13,9,0,*((ulonglong *) at_crossproduct)},
{"csc",13,9,0,*((ulonglong *) at_csc)},
{"csch",13,9,0,*((ulonglong *) at_csch)},
{"csolve",13,9,0,*((ulonglong *) at_csolve)| 1},
{"csv2gen",13,9,0,*((ulonglong *) at_csv2gen)},
{"cube",13,9,0,*((ulonglong *) at_cube)},
{"cumSum",13,9,0,*((ulonglong *) at_cumSum)},
{"cumsum",13,9,0,*((ulonglong *) at_cumsum)},
{"cumulated_frequencies",13,9,0,*((ulonglong *) at_cumulated_frequencies)},
{"curl",13,9,0,*((ulonglong *) at_curl)| 1},
{"current_sheet",13,9,0,*((ulonglong *) at_current_sheet)| 1},
{"curvature",13,9,0,*((ulonglong *) at_curvature)},
{"curve",13,9,0,*((ulonglong *) at_curve)},
{"cyan",13,2,0,*((ulonglong *) at_cyan)},
{"cycle2perm",13,9,0,*((ulonglong *) at_cycle2perm)},
{"cycleinv",13,9,0,*((ulonglong *) at_cycleinv)},
{"cycles2permu",13,9,0,*((ulonglong *) at_cycles2permu)},
{"cyclotomic",13,9,0,*((ulonglong *) at_cyclotomic)},
{"cylinder",13,9,0,*((ulonglong *) at_cylinder)},
{"czeros",13,9,0,*((ulonglong *) at_czeros)| 1},
{"dayofweek",13,9,0,*((ulonglong *) at_dayofweek)},
{"de",13,57,0,*((ulonglong *) at_de)| 1},
{"deSolve",13,77,0,*((ulonglong *) at_deSolve)| 1},
{"debug",13,9,0,*((ulonglong *) at_debug)| 1},
{"debug_infolevel",13,5,0,*((ulonglong *) at_debug_infolevel)},
{"debut_enregistrement",13,126,0,*((ulonglong *) at_debut_enregistrement)},
{"decrement",13,9,0,*((ulonglong *) at_decrement)| 1},
{"degree",13,9,0,*((ulonglong *) at_degree)},
{"del",13,77,0,*((ulonglong *) at_del)| 1},
{"delcols",13,9,0,*((ulonglong *) at_delcols)},
{"delrows",13,9,0,*((ulonglong *) at_delrows)},
{"deltalist",13,9,0,*((ulonglong *) at_deltalist)},
{"denom",13,9,0,*((ulonglong *) at_denom)},
{"densityplot",13,9,0,*((ulonglong *) at_densityplot)| 1},
{"deriver",13,9,0,*((ulonglong *) at_deriver)},
{"desolve",13,9,0,*((ulonglong *) at_desolve)| 1},
{"dessine_tortue",13,126,0,*((ulonglong *) at_dessine_tortue)},
{"det",13,9,0,*((ulonglong *) at_det)},
{"det_minor",13,9,0,*((ulonglong *) at_det_minor)},
{"developper",13,9,0,*((ulonglong *) at_developper)},
{"developper_transcendant",13,9,0,*((ulonglong *) at_developper_transcendant)},
{"dfc",13,9,0,*((ulonglong *) at_dfc)},
{"dfc2f",13,9,0,*((ulonglong *) at_dfc2f)},
{"diag",13,9,0,*((ulonglong *) at_diag)},
{"diff",13,9,0,*((ulonglong *) at_diff)| 1},
{"dim",13,9,0,*((ulonglong *) at_dim)},
{"display",13,9,0,*((ulonglong *) at_display)},
{"disque",13,126,0,*((ulonglong *) at_disque)},
{"disque_centre",13,126,0,*((ulonglong *) at_disque_centre)},
{"distance",13,9,0,*((ulonglong *) at_distance)},
{"distance2",13,9,0,*((ulonglong *) at_distance2)},
{"distanceat",13,9,0,*((ulonglong *) at_distanceat)| 1},
{"distanceatraw",13,9,0,*((ulonglong *) at_distanceatraw)},
{"div",13,22,0,*((ulonglong *) at_div)},
{"divcrement",13,9,0,*((ulonglong *) at_divcrement)| 1},
{"divergence",13,9,0,*((ulonglong *) at_divergence)| 1},
{"divide",13,9,0,*((ulonglong *) at_divide)},
{"divis",13,9,0,*((ulonglong *) at_divis)},
{"division_point",13,9,0,*((ulonglong *) at_division_point)},
{"divisors",13,9,0,*((ulonglong *) at_divisors)},
{"divmod",13,9,0,*((ulonglong *) at_divmod)},
{"divpc",13,9,0,*((ulonglong *) at_divpc)},
{"dodecahedron",13,9,0,*((ulonglong *) at_dodecahedron)},
{"domain",13,9,0,*((ulonglong *) at_domain)},
{"dot",13,9,0,*((ulonglong *) at_dot)},
{"dotP",13,9,0,*((ulonglong *) at_dotP)},
{"dot_paper",13,9,0,*((ulonglong *) at_dot_paper)},
{"dotprod",13,9,0,*((ulonglong *) at_dotprod)},
{"draw_string",13,9,0,*((ulonglong *) at_draw_string)},
{"droit",13,9,0,*((ulonglong *) at_droit)},
{"droite_tangente",13,9,0,*((ulonglong *) at_droite_tangente)},
{"dsolve",13,9,0,*((ulonglong *) at_dsolve)| 1},
{"dtype",13,9,0,*((ulonglong *) at_dtype)},
{"e2r",13,9,0,*((ulonglong *) at_e2r)},
{"ecart_type",13,9,0,*((ulonglong *) at_ecart_type)},
{"ecart_type_population",13,9,0,*((ulonglong *) at_ecart_type_population)},
{"ecris",13,126,0,*((ulonglong *) at_ecris)},
{"efface",13,126,0,*((ulonglong *) at_efface)},
{"egcd",13,9,0,*((ulonglong *) at_egcd)},
{"egv",13,9,0,*((ulonglong *) at_egv)},
{"egvl",13,9,0,*((ulonglong *) at_egvl)},
{"eigVc",13,9,0,*((ulonglong *) at_eigVc)},
{"eigVl",13,9,0,*((ulonglong *) at_eigVl)},
{"eigenvals",13,9,0,*((ulonglong *) at_eigenvals)},
{"eigenvalues",13,9,0,*((ulonglong *) at_eigenvalues)},
{"eigenvectors",13,9,0,*((ulonglong *) at_eigenvectors)},
{"eigenvects",13,9,0,*((ulonglong *) at_eigenvects)},
{"element",13,9,0,*((ulonglong *) at_element)},
{"eliminate",13,9,0,*((ulonglong *) at_eliminate)},
{"ellipse",13,9,0,*((ulonglong *) at_ellipse)},
{"entry",13,9,0,*((ulonglong *) at_entry)},
{"envelope",13,9,0,*((ulonglong *) at_envelope)},
{"epsilon2zero",13,9,0,*((ulonglong *) at_epsilon2zero)},
{"equal2diff",13,9,0,*((ulonglong *) at_equal2diff)},
{"equal2list",13,9,0,*((ulonglong *) at_equal2list)},
{"equation",13,9,0,*((ulonglong *) at_equation)},
{"equilateral_triangle",13,9,0,*((ulonglong *) at_equilateral_triangle)| 1},
{"erase3d",13,9,0,*((ulonglong *) at_erase3d)},
{"erf",13,9,0,*((ulonglong *) at_erf)},
{"erfc",13,9,0,*((ulonglong *) at_erfc)},
{"erfs",13,9,0,*((ulonglong *) at_erfs)},
{"et",13,33,0,*((ulonglong *) at_et)| 1},
{"euler",13,9,0,*((ulonglong *) at_euler)},
{"euler_mac_laurin",13,9,0,*((ulonglong *) at_euler_mac_laurin)},
{"eval",13,9,0,*((ulonglong *) at_eval)| 1},
{"eval_level",13,9,0,*((ulonglong *) at_eval_level)},
{"evala",13,9,0,*((ulonglong *) at_evala)},
{"evalb",13,9,0,*((ulonglong *) at_evalb)| 1},
{"evalc",13,9,0,*((ulonglong *) at_evalc)},
{"evalf",13,9,0,*((ulonglong *) at_evalf)},
{"evalfa",13,9,0,*((ulonglong *) at_evalfa)},
{"evalm",13,9,0,*((ulonglong *) at_evalm)},
{"even",13,9,0,*((ulonglong *) at_even)},
{"evolute",13,9,0,*((ulonglong *) at_evolute)},
{"exact",13,9,0,*((ulonglong *) at_exact)},
{"exbisector",13,9,0,*((ulonglong *) at_exbisector)},
{"excircle",13,9,0,*((ulonglong *) at_excircle)},
{"execute",13,9,0,*((ulonglong *) at_execute)},
{"exp",13,9,0,*((ulonglong *) at_exp)},
{"exp2list",13,9,0,*((ulonglong *) at_exp2list)| 1},
{"exp2pow",13,9,0,*((ulonglong *) at_exp2pow)},
{"exp2trig",13,9,0,*((ulonglong *) at_exp2trig)},
{"expexpand",13,9,0,*((ulonglong *) at_expexpand)},
{"expln2trig",13,9,0,*((ulonglong *) at_expln2trig)},
{"exponential",13,9,0,*((ulonglong *) at_exponential)},
{"exponential_cdf",13,9,0,*((ulonglong *) at_exponential_cdf)},
{"exponential_icdf",13,9,0,*((ulonglong *) at_exponential_icdf)},
{"exponential_regression",13,9,0,*((ulonglong *) at_exponential_regression)},
{"exponential_regression_plot",13,9,0,*((ulonglong *) at_exponential_regression_plot)},
{"exponentiald",13,9,0,*((ulonglong *) at_exponentiald)},
{"exponentiald_cdf",13,9,0,*((ulonglong *) at_exponentiald_cdf)},
{"exponentiald_icdf",13,9,0,*((ulonglong *) at_exponentiald_icdf)},
{"expr",13,9,0,*((ulonglong *) at_expr)},
{"extend",13,9,0,*((ulonglong *) at_extend)},
{"extract_measure",13,9,0,*((ulonglong *) at_extract_measure)},
{"extrema",13,9,0,*((ulonglong *) at_extrema)},
{"ezgcd",13,9,0,*((ulonglong *) at_ezgcd)},
{"f2nd",13,9,0,*((ulonglong *) at_f2nd)},
{"fMax",13,9,0,*((ulonglong *) at_fMax)},
{"fMin",13,9,0,*((ulonglong *) at_fMin)},
{"fPart",13,9,0,*((ulonglong *) at_fPart)},
{"faces",13,9,0,*((ulonglong *) at_faces)},
{"facteurs_premiers",13,9,0,*((ulonglong *) at_facteurs_premiers)},
{"factor",13,9,0,*((ulonglong *) at_factor)},
{"factor_xn",13,9,0,*((ulonglong *) at_factor_xn)},
{"factorial",13,9,0,*((ulonglong *) at_factorial)},
{"factoriser",13,9,0,*((ulonglong *) at_factoriser)},
{"factoriser_entier",13,9,0,*((ulonglong *) at_factoriser_entier)},
{"factoriser_sur_C",13,9,0,*((ulonglong *) at_factoriser_sur_C)},
{"factoriser_xn",13,9,0,*((ulonglong *) at_factoriser_xn)},
{"factors",13,9,0,*((ulonglong *) at_factors)},
{"faire",13,59,0,*((ulonglong *) at_faire)| 1},
{"fclose",13,9,0,*((ulonglong *) at_fclose)| 1},
{"fcoeff",13,9,0,*((ulonglong *) at_fcoeff)},
{"fft",13,9,0,*((ulonglong *) at_fft)},
{"fft_mult_size",13,9,0,*((ulonglong *) at_fft_mult_size)},
{"fieldplot",13,9,0,*((ulonglong *) at_fieldplot)},
{"filled",13,2,0,*((ulonglong *) at_filled)},
{"filter",13,9,0,*((ulonglong *) at_filter)},
{"fin_enregistrement",13,126,0,*((ulonglong *) at_fin_enregistrement)},
{"find",13,9,0,*((ulonglong *) at_find)},
{"findhelp",13,9,0,*((ulonglong *) at_findhelp)| 1},
{"fisher",13,9,0,*((ulonglong *) at_fisher)},
{"fisher_cdf",13,9,0,*((ulonglong *) at_fisher_cdf)},
{"fisher_icdf",13,9,0,*((ulonglong *) at_fisher_icdf)},
{"fisherd",13,9,0,*((ulonglong *) at_fisherd)},
{"fisherd_cdf",13,9,0,*((ulonglong *) at_fisherd_cdf)},
{"fisherd_icdf",13,9,0,*((ulonglong *) at_fisherd_icdf)},
{"flatten",13,9,0,*((ulonglong *) at_flatten)},
{"flatten1",13,9,0,*((ulonglong *) at_flatten1)},
{"float",13,9,0,*((ulonglong *) at_float)},
{"float2rational",13,9,0,*((ulonglong *) at_float2rational)},
{"floor",13,9,0,*((ulonglong *) at_floor)},
{"fonction",13,73,0,*((ulonglong *) at_fonction)| 1},
{"fonction_derivee",13,9,0,*((ulonglong *) at_fonction_derivee)},
{"fopen",13,9,0,*((ulonglong *) at_fopen)},
{"format",13,9,0,*((ulonglong *) at_format)},
{"forward",13,9,0,*((ulonglong *) at_forward)},
{"fourier_an",13,9,0,*((ulonglong *) at_fourier_an)},
{"fourier_bn",13,9,0,*((ulonglong *) at_fourier_bn)},
{"fourier_cn",13,9,0,*((ulonglong *) at_fourier_cn)},
{"fprint",13,9,0,*((ulonglong *) at_fprint)},
{"frac",13,9,0,*((ulonglong *) at_frac)},
{"fracmod",13,9,0,*((ulonglong *) at_fracmod)},
{"frame_2d",13,9,0,*((ulonglong *) at_frame_2d)},
{"frame_3d",13,9,0,*((ulonglong *) at_frame_3d)},
{"frenet",13,9,0,*((ulonglong *) at_frenet)},
{"frequencies",13,9,0,*((ulonglong *) at_frequencies)},
{"frexp",13,9,0,*((ulonglong *) at_frexp)},
{"frobenius_norm",13,9,0,*((ulonglong *) at_frobenius_norm)},
{"froot",13,9,0,*((ulonglong *) at_froot)},
{"fsolve",13,9,0,*((ulonglong *) at_fsolve)| 1},
{"funcplot",13,9,0,*((ulonglong *) at_funcplot)| 1},
{"function_diff",13,9,0,*((ulonglong *) at_function_diff)},
{"fxnd",13,9,0,*((ulonglong *) at_fxnd)},
{"galoisconj",13,9,0,*((ulonglong *) at_galoisconj)},
{"gammad",13,9,0,*((ulonglong *) at_gammad)},
{"gammad_cdf",13,9,0,*((ulonglong *) at_gammad_cdf)},
{"gammad_icdf",13,9,0,*((ulonglong *) at_gammad_icdf)},
{"gauche",13,9,0,*((ulonglong *) at_gauche)},
{"gauss",13,9,0,*((ulonglong *) at_gauss)},
{"gauss_seidel_linsolve",13,9,0,*((ulonglong *) at_gauss_seidel_linsolve)},
{"gaussian_window",13,9,0,*((ulonglong *) at_gaussian_window)},
{"gaussjord",13,9,0,*((ulonglong *) at_gaussjord)},
{"gaussquad",13,9,0,*((ulonglong *) at_gaussquad)},
{"gbasis",13,9,0,*((ulonglong *) at_gbasis)},
{"gcd",13,9,0,*((ulonglong *) at_gcd)},
{"gcdex",13,9,0,*((ulonglong *) at_gcdex)},
{"genpoly",13,9,0,*((ulonglong *) at_genpoly)},
{"geo2d",13,9,0,*((ulonglong *) at_geo2d)},
{"geo3d",13,9,0,*((ulonglong *) at_geo3d)},
{"geometric",13,9,0,*((ulonglong *) at_geometric)},
{"geometric_cdf",13,9,0,*((ulonglong *) at_geometric_cdf)},
{"geometric_icdf",13,9,0,*((ulonglong *) at_geometric_icdf)},
{"getDenom",13,9,0,*((ulonglong *) at_getDenom)},
{"getKey",13,9,0,*((ulonglong *) at_getKey)},
{"getNum",13,9,0,*((ulonglong *) at_getNum)},
{"getType",13,9,0,*((ulonglong *) at_getType)},
{"get_pixel",13,9,0,*((ulonglong *) at_get_pixel)},
{"ggb_ang",13,9,0,*((ulonglong *) at_ggb_ang)},
{"ggbalt",13,9,0,*((ulonglong *) at_ggbalt)},
{"ggbsort",13,9,0,*((ulonglong *) at_ggbsort)},
{"giac",13,9,0,*((ulonglong *) at_giac)},
{"goto",13,77,0,*((ulonglong *) at_goto)},
{"grad",13,9,0,*((ulonglong *) at_grad)| 1},
{"gramschmidt",13,9,0,*((ulonglong *) at_gramschmidt)},
{"graph2tex",13,9,0,*((ulonglong *) at_graph2tex)},
{"graph3d2tex",13,9,0,*((ulonglong *) at_graph3d2tex)},
{"graph_scc",13,9,0,*((ulonglong *) at_graph_scc)},
{"graphe",13,9,0,*((ulonglong *) at_graphe)| 1},
{"graphe3d",13,9,0,*((ulonglong *) at_graphe3d)},
{"graphe_suite",13,9,0,*((ulonglong *) at_graphe_suite)},
{"greduce",13,9,0,*((ulonglong *) at_greduce)},
{"green",13,2,0,*((ulonglong *) at_green)},
{"grid_paper",13,9,0,*((ulonglong *) at_grid_paper)},
{"groupermu",13,9,0,*((ulonglong *) at_groupermu)},
{"hadamard",13,9,0,*((ulonglong *) at_hadamard)},
{"half_cone",13,9,0,*((ulonglong *) at_half_cone)},
{"half_line",13,9,0,*((ulonglong *) at_half_line)},
{"halftan",13,9,0,*((ulonglong *) at_halftan)},
{"halftan_hyp2exp",13,9,0,*((ulonglong *) at_halftan_hyp2exp)},
{"halt",13,9,0,*((ulonglong *) at_halt)| 1},
{"hamdist",13,9,0,*((ulonglong *) at_hamdist)},
{"hamming_window",13,9,0,*((ulonglong *) at_hamming_window)},
{"hann_poisson_window",13,9,0,*((ulonglong *) at_hann_poisson_window)},
{"hann_window",13,9,0,*((ulonglong *) at_hann_window)},
{"harmonic",13,9,0,*((ulonglong *) at_harmonic)},
{"harmonic_conjugate",13,9,0,*((ulonglong *) at_harmonic_conjugate)},
{"harmonic_division",13,9,0,*((ulonglong *) at_harmonic_division)| 1},
{"has",13,9,0,*((ulonglong *) at_has)},
{"hasard",13,77,0,*((ulonglong *) at_hasard)},
{"head",13,9,0,*((ulonglong *) at_head)},
{"heading",13,9,0,*((ulonglong *) at_heading)},
{"heap_mult",13,9,0,*((ulonglong *) at_heap_mult)},
{"heapify",13,9,0,*((ulonglong *) at_heapify)},
{"heappop",13,9,0,*((ulonglong *) at_heappop)},
{"heappush",13,9,0,*((ulonglong *) at_heappush)},
{"help",13,9,0,*((ulonglong *) at_help)| 1},
{"hermite",13,9,0,*((ulonglong *) at_hermite)},
{"hessenberg",13,9,0,*((ulonglong *) at_hessenberg)},
{"hessian",13,9,0,*((ulonglong *) at_hessian)| 1},
{"heugcd",13,9,0,*((ulonglong *) at_heugcd)},
{"hexagon",13,9,0,*((ulonglong *) at_hexagon)| 1},
{"hexprint",13,9,0,*((ulonglong *) at_hexprint)},
{"hidden_name",13,2,0,*((ulonglong *) at_hidden_name)},
{"hideturtle",13,9,0,*((ulonglong *) at_hideturtle)},
{"highpass",13,9,0,*((ulonglong *) at_highpass)},
{"hilbert",13,9,0,*((ulonglong *) at_hilbert)},
{"histogram",13,9,0,*((ulonglong *) at_histogram)},
{"hold",13,9,0,*((ulonglong *) at_hold)| 1},
{"homothety",13,9,0,*((ulonglong *) at_homothety)},
{"horner",13,9,0,*((ulonglong *) at_horner)},
{"hp38",13,9,0,*((ulonglong *) at_hp38)},
{"hyp2exp",13,9,0,*((ulonglong *) at_hyp2exp)},
{"hyperbola",13,9,0,*((ulonglong *) at_hyperbola)},
{"hyperplan",13,9,0,*((ulonglong *) at_hyperplan)},
{"hypersphere",13,9,0,*((ulonglong *) at_hypersphere)},
{"hypersurface",13,9,0,*((ulonglong *) at_hypersurface)},
{"iPart",13,9,0,*((ulonglong *) at_iPart)},
{"iabcuv",13,9,0,*((ulonglong *) at_iabcuv)},
{"ibasis",13,9,0,*((ulonglong *) at_ibasis)},
{"ibpdv",13,9,0,*((ulonglong *) at_ibpdv)},
{"ibpu",13,9,0,*((ulonglong *) at_ibpu)},
{"icdf",13,9,0,*((ulonglong *) at_icdf)},
{"ichinrem",13,9,0,*((ulonglong *) at_ichinrem)},
{"ichrem",13,9,0,*((ulonglong *) at_ichrem)},
{"icontent",13,9,0,*((ulonglong *) at_icontent)},
{"icosahedron",13,9,0,*((ulonglong *) at_icosahedron)},
{"id",13,9,0,*((ulonglong *) at_id)},
{"identity",13,9,0,*((ulonglong *) at_identity)},
{"idivis",13,9,0,*((ulonglong *) at_idivis)},
{"idn",13,9,0,*((ulonglong *) at_idn)},
{"iegcd",13,9,0,*((ulonglong *) at_iegcd)},
{"ifactor",13,9,0,*((ulonglong *) at_ifactor)},
{"ifactors",13,9,0,*((ulonglong *) at_ifactors)},
{"ifft",13,9,0,*((ulonglong *) at_ifft)},
{"igamma",13,9,0,*((ulonglong *) at_igamma)},
{"igamma_exp",13,9,0,*((ulonglong *) at_igamma_exp)},
{"igcd",13,9,0,*((ulonglong *) at_igcd)},
{"igcdex",13,9,0,*((ulonglong *) at_igcdex)},
{"ihermite",13,9,0,*((ulonglong *) at_ihermite)},
{"ilaplace",13,9,0,*((ulonglong *) at_ilaplace)},
{"im",13,9,0,*((ulonglong *) at_im)},
{"imag",13,9,0,*((ulonglong *) at_imag)},
{"image",13,9,0,*((ulonglong *) at_image)},
{"implicit_diff",13,9,0,*((ulonglong *) at_implicit_diff)},
{"implicitdiff",13,9,0,*((ulonglong *) at_implicitdiff)},
{"implicitplot",13,9,0,*((ulonglong *) at_implicitplot)},
{"implicitplot3d",13,9,0,*((ulonglong *) at_implicitplot3d)},
{"inString",13,9,0,*((ulonglong *) at_inString)},
{"in_ideal",13,9,0,*((ulonglong *) at_in_ideal)},
{"incircle",13,9,0,*((ulonglong *) at_incircle)},
{"increment",13,9,0,*((ulonglong *) at_increment)| 1},
{"indets",13,9,0,*((ulonglong *) at_indets)},
{"index",13,9,0,*((ulonglong *) at_index)},
{"inequationplot",13,9,0,*((ulonglong *) at_inequationplot)| 1},
{"inferieur_strict_sort",13,9,0,*((ulonglong *) at_inferieur_strict_sort)},
{"innertln",13,9,0,*((ulonglong *) at_innertln)},
{"input",13,9,0,*((ulonglong *) at_input)| 1},
{"inputform",13,9,0,*((ulonglong *) at_inputform)| 1},
{"insert",13,9,0,*((ulonglong *) at_insert)},
{"insmod",13,9,0,*((ulonglong *) at_insmod)},
{"int",13,9,0,*((ulonglong *) at_int)| 1},
{"intDiv",13,9,0,*((ulonglong *) at_intDiv)},
{"integer_format",13,9,0,*((ulonglong *) at_integer_format)},
{"integrate",13,9,0,*((ulonglong *) at_integrate)| 1},
{"integrer",13,9,0,*((ulonglong *) at_integrer)},
{"inter",13,9,0,*((ulonglong *) at_inter)},
{"interactive",13,9,0,*((ulonglong *) at_interactive)| 1},
{"interactive_odeplot",13,9,0,*((ulonglong *) at_interactive_odeplot)},
{"interactive_plotode",13,9,0,*((ulonglong *) at_interactive_plotode)},
{"interp",13,9,0,*((ulonglong *) at_interp)},
{"interval2center",13,9,0,*((ulonglong *) at_interval2center)},
{"inv",13,9,0,*((ulonglong *) at_inv)},
{"invd_blocksize",13,9,0,*((ulonglong *) at_invd_blocksize)},
{"inverse",13,9,0,*((ulonglong *) at_inverse)},
{"inversion",13,9,0,*((ulonglong *) at_inversion)},
{"invlaplace",13,9,0,*((ulonglong *) at_invlaplace)},
{"invztrans",13,9,0,*((ulonglong *) at_invztrans)},
{"iquo",13,9,0,*((ulonglong *) at_iquo)},
{"iquorem",13,9,0,*((ulonglong *) at_iquorem)},
{"iquosto",13,9,0,*((ulonglong *) at_iquosto)| 1},
{"iratrecon",13,9,0,*((ulonglong *) at_iratrecon)},
{"irem",13,9,0,*((ulonglong *) at_irem)},
{"iremsto",13,9,0,*((ulonglong *) at_iremsto)| 1},
{"isPrime",13,9,0,*((ulonglong *) at_isPrime)},
{"is_3dpoint",13,9,0,*((ulonglong *) at_is_3dpoint)},
{"is_collinear",13,9,0,*((ulonglong *) at_is_collinear)},
{"is_concyclic",13,9,0,*((ulonglong *) at_is_concyclic)},
{"is_conjugate",13,9,0,*((ulonglong *) at_is_conjugate)},
{"is_coplanar",13,9,0,*((ulonglong *) at_is_coplanar)},
{"is_cospherical",13,9,0,*((ulonglong *) at_is_cospherical)},
{"is_cycle",13,9,0,*((ulonglong *) at_is_cycle)},
{"is_element",13,9,0,*((ulonglong *) at_is_element)},
{"is_equilateral",13,9,0,*((ulonglong *) at_is_equilateral)},
{"is_harmonic",13,9,0,*((ulonglong *) at_is_harmonic)},
{"is_harmonic_circle_bundle",13,9,0,*((ulonglong *) at_is_harmonic_circle_bundle)},
{"is_harmonic_line_bundle",13,9,0,*((ulonglong *) at_is_harmonic_line_bundle)},
{"is_included",13,9,0,*((ulonglong *) at_is_included)},
{"is_inside",13,9,0,*((ulonglong *) at_is_inside)},
{"is_isosceles",13,9,0,*((ulonglong *) at_is_isosceles)},
{"is_orthogonal",13,9,0,*((ulonglong *) at_is_orthogonal)},
{"is_parallel",13,9,0,*((ulonglong *) at_is_parallel)},
{"is_parallelogram",13,9,0,*((ulonglong *) at_is_parallelogram)},
{"is_permu",13,9,0,*((ulonglong *) at_is_permu)},
{"is_perpendicular",13,9,0,*((ulonglong *) at_is_perpendicular)},
{"is_polynomial",13,9,0,*((ulonglong *) at_is_polynomial)},
{"is_prime",13,9,0,*((ulonglong *) at_is_prime)},
{"is_pseudoprime",13,9,0,*((ulonglong *) at_is_pseudoprime)},
{"is_rectangle",13,9,0,*((ulonglong *) at_is_rectangle)},
{"is_rhombus",13,9,0,*((ulonglong *) at_is_rhombus)},
{"is_square",13,9,0,*((ulonglong *) at_is_square)},
{"isfinite",13,9,0,*((ulonglong *) at_isfinite)},
{"isinf",13,9,0,*((ulonglong *) at_isinf)},
{"ismith",13,9,0,*((ulonglong *) at_ismith)},
{"isnan",13,9,0,*((ulonglong *) at_isnan)},
{"isobarycenter",13,9,0,*((ulonglong *) at_isobarycenter)},
{"isom",13,9,0,*((ulonglong *) at_isom)},
{"isopolygon",13,9,0,*((ulonglong *) at_isopolygon)},
{"isosceles_triangle",13,9,0,*((ulonglong *) at_isosceles_triangle)| 1},
{"isprime",13,9,0,*((ulonglong *) at_isprime)},
{"ithprime",13,9,0,*((ulonglong *) at_ithprime)},
{"jacobi_linsolve",13,9,0,*((ulonglong *) at_jacobi_linsolve)},
{"jacobi_symbol",13,9,0,*((ulonglong *) at_jacobi_symbol)},
{"javascript",13,9,0,*((ulonglong *) at_javascript)| 1},
{"join",13,9,0,*((ulonglong *) at_join)},
{"jordan",13,9,0,*((ulonglong *) at_jordan)},
{"jump",13,126,0,*((ulonglong *) at_jump)},
{"jusque",13,58,0,*((ulonglong *) at_jusque)| 1},
{"ker",13,9,0,*((ulonglong *) at_ker)},
{"kernel",13,9,0,*((ulonglong *) at_kernel)},
{"keyboard",13,9,0,*((ulonglong *) at_keyboard)},
{"kill",13,9,0,*((ulonglong *) at_kill)},
{"kolmogorovd",13,9,0,*((ulonglong *) at_kolmogorovd)},
{"kolmogorovt",13,9,0,*((ulonglong *) at_kolmogorovt)},
{"l1norm",13,9,0,*((ulonglong *) at_l1norm)},
{"l2norm",13,9,0,*((ulonglong *) at_l2norm)},
{"label",13,77,0,*((ulonglong *) at_label)},
{"lagrange",13,9,0,*((ulonglong *) at_lagrange)},
{"laguerre",13,9,0,*((ulonglong *) at_laguerre)},
{"lapack_limit",13,9,0,*((ulonglong *) at_lapack_limit)},
{"laplace",13,9,0,*((ulonglong *) at_laplace)},
{"laplacian",13,9,0,*((ulonglong *) at_laplacian)| 1},
{"latex",13,9,0,*((ulonglong *) at_latex)},
{"lcm",13,9,0,*((ulonglong *) at_lcm)},
{"lcoeff",13,9,0,*((ulonglong *) at_lcoeff)},
{"ldegree",13,9,0,*((ulonglong *) at_ldegree)},
{"ldexp",13,9,0,*((ulonglong *) at_ldexp)},
{"left",13,9,0,*((ulonglong *) at_left)},
{"legend",13,9,0,*((ulonglong *) at_legend)| 1},
{"legendre",13,9,0,*((ulonglong *) at_legendre)},
{"legendre_symbol",13,9,0,*((ulonglong *) at_legendre_symbol)},
{"len",13,9,0,*((ulonglong *) at_len)},
{"length",13,9,0,*((ulonglong *) at_length)},
{"leve_crayon",13,126,0,*((ulonglong *) at_leve_crayon)},
{"lgcd",13,9,0,*((ulonglong *) at_lgcd)},
{"lhs",13,9,0,*((ulonglong *) at_lhs)},
{"ligne_polygonale",13,9,0,*((ulonglong *) at_ligne_polygonale)},
{"ligne_polygonale_pointee",13,9,0,*((ulonglong *) at_ligne_polygonale_pointee)},
{"limit",13,9,0,*((ulonglong *) at_limit)| 1},
{"limite",13,9,0,*((ulonglong *) at_limite)},
{"lin",13,9,0,*((ulonglong *) at_lin)},
{"line",13,9,0,*((ulonglong *) at_line)| 1},
{"line_inter",13,9,0,*((ulonglong *) at_line_inter)},
{"line_paper",13,9,0,*((ulonglong *) at_line_paper)},
{"line_segments",13,9,0,*((ulonglong *) at_line_segments)},
{"linear_interpolate",13,9,0,*((ulonglong *) at_linear_interpolate)},
{"linear_regression",13,9,0,*((ulonglong *) at_linear_regression)},
{"linear_regression_plot",13,9,0,*((ulonglong *) at_linear_regression_plot)},
{"lineariser",13,9,0,*((ulonglong *) at_lineariser)},
{"lineariser_trigo",13,9,0,*((ulonglong *) at_lineariser_trigo)},
{"linfnorm",13,9,0,*((ulonglong *) at_linfnorm)},
{"link2giac",13,9,0,*((ulonglong *) at_link2giac)},
{"linsolve",13,9,0,*((ulonglong *) at_linsolve)| 1},
{"linspace",13,9,0,*((ulonglong *) at_linspace)},
{"lis",13,77,0,*((ulonglong *) at_lis)| 1},
{"lis_phrase",13,77,0,*((ulonglong *) at_lis_phrase)| 1},
{"list2exp",13,9,0,*((ulonglong *) at_list2exp)},
{"list2mat",13,9,0,*((ulonglong *) at_list2mat)},
{"listplot",13,9,0,*((ulonglong *) at_listplot)},
{"lll",13,9,0,*((ulonglong *) at_lll)},
{"lll_reduce",13,9,0,*((ulonglong *) at_lll_reduce)},
{"ln",13,9,0,*((ulonglong *) at_ln)},
{"lnGamma_minus",13,9,0,*((ulonglong *) at_lnGamma_minus)},
{"lname",13,9,0,*((ulonglong *) at_lname)},
{"lncollect",13,9,0,*((ulonglong *) at_lncollect)},
{"lnexpand",13,9,0,*((ulonglong *) at_lnexpand)},
{"locus",13,9,0,*((ulonglong *) at_locus)| 1},
{"log10",13,9,0,*((ulonglong *) at_log10)},
{"logarithmic_regression",13,9,0,*((ulonglong *) at_logarithmic_regression)},
{"logarithmic_regression_plot",13,9,0,*((ulonglong *) at_logarithmic_regression_plot)},
{"logb",13,9,0,*((ulonglong *) at_logb)},
{"logistic_regression",13,9,0,*((ulonglong *) at_logistic_regression)},
{"logistic_regression_plot",13,9,0,*((ulonglong *) at_logistic_regression_plot)},
{"lower",13,9,0,*((ulonglong *) at_lower)},
{"lowpass",13,9,0,*((ulonglong *) at_lowpass)},
{"lpsolve",13,9,0,*((ulonglong *) at_lpsolve)},
{"lsmod",13,9,0,*((ulonglong *) at_lsmod)},
{"lsq",13,9,0,*((ulonglong *) at_lsq)},
{"lu",13,9,0,*((ulonglong *) at_lu)},
{"lvar",13,9,0,*((ulonglong *) at_lvar)},
{"mRow",13,9,0,*((ulonglong *) at_mRow)},
{"mRowAdd",13,9,0,*((ulonglong *) at_mRowAdd)},
{"magenta",13,2,0,*((ulonglong *) at_magenta)},
{"makelist",13,9,0,*((ulonglong *) at_makelist)},
{"makemat",13,9,0,*((ulonglong *) at_makemat)},
{"makemod",13,9,0,*((ulonglong *) at_makemod)},
{"makesuite",13,9,0,*((ulonglong *) at_makesuite)},
{"makevector",13,9,0,*((ulonglong *) at_makevector)},
{"mantissa",13,9,0,*((ulonglong *) at_mantissa)},
{"map",13,9,0,*((ulonglong *) at_map)},
{"maple2mupad",13,9,0,*((ulonglong *) at_maple2mupad)| 1},
{"maple2xcas",13,9,0,*((ulonglong *) at_maple2xcas)| 1},
{"maple_ifactors",13,9,0,*((ulonglong *) at_maple_ifactors)},
{"maple_mode",13,9,0,*((ulonglong *) at_maple_mode)},
{"markov",13,9,0,*((ulonglong *) at_markov)},
{"mat2list",13,9,0,*((ulonglong *) at_mat2list)},
{"mathml",13,9,0,*((ulonglong *) at_mathml)},
{"matpow",13,9,0,*((ulonglong *) at_matpow)},
{"matrix",13,9,0,*((ulonglong *) at_matrix)},
{"matrix_norm",13,9,0,*((ulonglong *) at_matrix_norm)},
{"max",13,9,0,*((ulonglong *) at_max)},
{"max_algext",13,9,0,*((ulonglong *) at_max_algext)},
{"maximize",13,9,0,*((ulonglong *) at_maximize)},
{"maxnorm",13,9,0,*((ulonglong *) at_maxnorm)},
{"mean",13,9,0,*((ulonglong *) at_mean)},
{"median",13,9,0,*((ulonglong *) at_median)},
{"median_line",13,9,0,*((ulonglong *) at_median_line)},
{"member",13,9,0,*((ulonglong *) at_member)| 1},
{"mgf",13,9,0,*((ulonglong *) at_mgf)},
{"mid",13,9,0,*((ulonglong *) at_mid)},
{"midpoint",13,9,0,*((ulonglong *) at_midpoint)},
{"min",13,9,0,*((ulonglong *) at_min)},
{"min_proba_time",13,9,0,*((ulonglong *) at_min_proba_time)},
{"minimax",13,9,0,*((ulonglong *) at_minimax)},
{"minimize",13,9,0,*((ulonglong *) at_minimize)},
{"mkisom",13,9,0,*((ulonglong *) at_mkisom)},
{"mksa",13,9,0,*((ulonglong *) at_mksa)},
{"modgcd",13,9,0,*((ulonglong *) at_modgcd)},
{"modgcd_cachesize",13,9,0,*((ulonglong *) at_modgcd_cachesize)},
{"modp",13,9,0,*((ulonglong *) at_modp)},
{"mods",13,9,0,*((ulonglong *) at_mods)},
{"montre_tortue",13,126,0,*((ulonglong *) at_montre_tortue)},
{"moustache",13,9,0,*((ulonglong *) at_moustache)},
{"moyal",13,9,0,*((ulonglong *) at_moyal)},
{"moyenne",13,9,0,*((ulonglong *) at_moyenne)},
{"mpzclass_allowed",13,9,0,*((ulonglong *) at_mpzclass_allowed)},
{"mul",13,9,0,*((ulonglong *) at_mul)},
{"mult_c_conjugate",13,9,0,*((ulonglong *) at_mult_c_conjugate)| 1},
{"mult_conjugate",13,9,0,*((ulonglong *) at_mult_conjugate)},
{"multcrement",13,9,0,*((ulonglong *) at_multcrement)| 1},
{"multinomial",13,9,0,*((ulonglong *) at_multinomial)},
{"multiplier_conjugue",13,9,0,*((ulonglong *) at_multiplier_conjugue)},
{"multiplier_conjugue_complexe",13,9,0,*((ulonglong *) at_multiplier_conjugue_complexe)},
{"multiply",13,9,0,*((ulonglong *) at_multiply)},
{"mupad2maple",13,9,0,*((ulonglong *) at_mupad2maple)| 1},
{"mupad2xcas",13,9,0,*((ulonglong *) at_mupad2xcas)| 1},
{"nCr",13,9,0,*((ulonglong *) at_nCr)},
{"nDeriv",13,9,0,*((ulonglong *) at_nDeriv)},
{"nInt",13,9,0,*((ulonglong *) at_nInt)},
{"nPr",13,9,0,*((ulonglong *) at_nPr)},
{"nSolve",13,9,0,*((ulonglong *) at_nSolve)},
{"ncols",13,9,0,*((ulonglong *) at_ncols)},
{"negbinomial",13,9,0,*((ulonglong *) at_negbinomial)},
{"negbinomial_cdf",13,9,0,*((ulonglong *) at_negbinomial_cdf)},
{"negbinomial_icdf",13,9,0,*((ulonglong *) at_negbinomial_icdf)},
{"newList",13,9,0,*((ulonglong *) at_newList)},
{"newMat",13,9,0,*((ulonglong *) at_newMat)},
{"newton",13,9,0,*((ulonglong *) at_newton)},
{"nextperm",13,9,0,*((ulonglong *) at_nextperm)},
{"nextprime",13,9,0,*((ulonglong *) at_nextprime)},
{"nlpsolve",13,9,0,*((ulonglong *) at_nlpsolve)},
{"nodisp",13,9,0,*((ulonglong *) at_nodisp)},
{"non",13,11,0,*((ulonglong *) at_non)},
{"non_recursive_normal",13,9,0,*((ulonglong *) at_non_recursive_normal)},
{"nop",13,9,0,*((ulonglong *) at_nop)},
{"nops",13,9,0,*((ulonglong *) at_nops)},
{"norm",13,9,0,*((ulonglong *) at_norm)},
{"normal",13,9,0,*((ulonglong *) at_normal)},
{"normal_cdf",13,9,0,*((ulonglong *) at_normal_cdf)},
{"normal_icdf",13,9,0,*((ulonglong *) at_normal_icdf)},
{"normald",13,9,0,*((ulonglong *) at_normald)},
{"normald_cdf",13,9,0,*((ulonglong *) at_normald_cdf)},
{"normald_icdf",13,9,0,*((ulonglong *) at_normald_icdf)},
{"normalize",13,9,0,*((ulonglong *) at_normalize)},
{"normalt",13,9,0,*((ulonglong *) at_normalt)},
{"nprimes",13,9,0,*((ulonglong *) at_nprimes)},
{"nrows",13,9,0,*((ulonglong *) at_nrows)},
{"nuage_points",13,9,0,*((ulonglong *) at_nuage_points)},
{"nullspace",13,9,0,*((ulonglong *) at_nullspace)},
{"numer",13,9,0,*((ulonglong *) at_numer)},
{"octahedron",13,9,0,*((ulonglong *) at_octahedron)},
{"octprint",13,9,0,*((ulonglong *) at_octprint)},
{"odd",13,9,0,*((ulonglong *) at_odd)},
{"odeplot",13,9,0,*((ulonglong *) at_odeplot)},
{"odesolve",13,9,0,*((ulonglong *) at_odesolve)},
{"op",13,9,0,*((ulonglong *) at_op)},
{"open",13,9,0,*((ulonglong *) at_open)},
{"open_polygon",13,9,0,*((ulonglong *) at_open_polygon)},
{"or",13,33,0,*((ulonglong *) at_or)| 1},
{"ord",13,9,0,*((ulonglong *) at_ord)},
{"order_size",13,9,0,*((ulonglong *) at_order_size)},
{"ordinate",13,9,0,*((ulonglong *) at_ordinate)},
{"orthocenter",13,9,0,*((ulonglong *) at_orthocenter)},
{"orthogonal",13,9,0,*((ulonglong *) at_orthogonal)},
{"os_version",13,9,0,*((ulonglong *) at_os_version)},
{"osculating_circle",13,9,0,*((ulonglong *) at_osculating_circle)},
{"ou",13,33,0,*((ulonglong *) at_ou)| 1},
{"output",13,9,0,*((ulonglong *) at_output)| 1},
{"p1oc2",13,9,0,*((ulonglong *) at_p1oc2)},
{"p1op2",13,9,0,*((ulonglong *) at_p1op2)},
{"pa2b2",13,9,0,*((ulonglong *) at_pa2b2)},
{"pade",13,9,0,*((ulonglong *) at_pade)},
{"padic_linsolve",13,9,0,*((ulonglong *) at_padic_linsolve)},
{"parabola",13,9,0,*((ulonglong *) at_parabola)},
{"parabolic_interpolate",13,9,0,*((ulonglong *) at_parabolic_interpolate)},
{"parallel",13,9,0,*((ulonglong *) at_parallel)},
{"parallelepiped",13,9,0,*((ulonglong *) at_parallelepiped)},
{"parallelogram",13,9,0,*((ulonglong *) at_parallelogram)| 1},
{"parameq",13,9,0,*((ulonglong *) at_parameq)},
{"parameter",13,9,0,*((ulonglong *) at_parameter)},
{"paramplot",13,9,0,*((ulonglong *) at_paramplot)| 1},
{"pari",13,9,0,*((ulonglong *) at_pari)| 1},
{"pari_unlock",13,9,0,*((ulonglong *) at_pari_unlock)| 1},
{"part",13,9,0,*((ulonglong *) at_part)},
{"partfrac",13,9,0,*((ulonglong *) at_partfrac)},
{"parzen_window",13,9,0,*((ulonglong *) at_parzen_window)},
{"pas",13,60,0,*((ulonglong *) at_pas)| 1},
{"pas_de_cote",13,126,0,*((ulonglong *) at_pas_de_cote)},
{"pcar",13,9,0,*((ulonglong *) at_pcar)},
{"pcar_hessenberg",13,9,0,*((ulonglong *) at_pcar_hessenberg)},
{"pcoeff",13,9,0,*((ulonglong *) at_pcoeff)},
{"pencolor",13,126,0,*((ulonglong *) at_pencolor)},
{"pendown",13,126,0,*((ulonglong *) at_pendown)},
{"penup",13,126,0,*((ulonglong *) at_penup)},
{"perimeter",13,9,0,*((ulonglong *) at_perimeter)},
{"perimeterat",13,9,0,*((ulonglong *) at_perimeterat)| 1},
{"perimeteratraw",13,9,0,*((ulonglong *) at_perimeteratraw)},
{"periodic",13,9,0,*((ulonglong *) at_periodic)},
{"perm",13,9,0,*((ulonglong *) at_perm)},
{"perminv",13,9,0,*((ulonglong *) at_perminv)},
{"permu2cycles",13,9,0,*((ulonglong *) at_permu2cycles)},
{"permu2mat",13,9,0,*((ulonglong *) at_permu2mat)},
{"permuorder",13,9,0,*((ulonglong *) at_permuorder)},
{"perpen_bisector",13,9,0,*((ulonglong *) at_perpen_bisector)},
{"perpendicular",13,9,0,*((ulonglong *) at_perpendicular)},
{"peval",13,9,0,*((ulonglong *) at_peval)},
{"piecewise",13,9,0,*((ulonglong *) at_piecewise)| 1},
{"pivot",13,9,0,*((ulonglong *) at_pivot)},
{"pixoff",13,9,0,*((ulonglong *) at_pixoff)},
{"pixon",13,9,0,*((ulonglong *) at_pixon)},
{"plane",13,9,0,*((ulonglong *) at_plane)},
{"playsnd",13,9,0,*((ulonglong *) at_playsnd)},
{"plot",13,9,0,*((ulonglong *) at_plot)| 1},
{"plot3d",13,9,0,*((ulonglong *) at_plot3d)},
{"plot_style",13,9,0,*((ulonglong *) at_plot_style)},
{"plotarea",13,9,0,*((ulonglong *) at_plotarea)},
{"plotcdf",13,9,0,*((ulonglong *) at_plotcdf)},
{"plotcontour",13,9,0,*((ulonglong *) at_plotcontour)| 1},
{"plotdensity",13,9,0,*((ulonglong *) at_plotdensity)| 1},
{"plotfield",13,9,0,*((ulonglong *) at_plotfield)},
{"plotfunc",13,9,0,*((ulonglong *) at_plotfunc)| 1},
{"plotimplicit",13,9,0,*((ulonglong *) at_plotimplicit)},
{"plotinequation",13,9,0,*((ulonglong *) at_plotinequation)| 1},
{"plotlist",13,9,0,*((ulonglong *) at_plotlist)},
{"plotmatrix",13,9,0,*((ulonglong *) at_plotmatrix)| 1},
{"plotode",13,9,0,*((ulonglong *) at_plotode)},
{"plotparam",13,9,0,*((ulonglong *) at_plotparam)| 1},
{"plotpolar",13,9,0,*((ulonglong *) at_plotpolar)| 1},
{"plotproba",13,9,0,*((ulonglong *) at_plotproba)| 1},
{"plotseq",13,9,0,*((ulonglong *) at_plotseq)},
{"pmin",13,9,0,*((ulonglong *) at_pmin)},
{"pnt",13,9,0,*((ulonglong *) at_pnt)},
{"point",13,9,0,*((ulonglong *) at_point)},
{"point2d",13,9,0,*((ulonglong *) at_point2d)| 1},
{"point3d",13,9,0,*((ulonglong *) at_point3d)| 1},
{"pointer",13,9,0,*((ulonglong *) at_pointer)},
{"poisson",13,9,0,*((ulonglong *) at_poisson)},
{"poisson_cdf",13,9,0,*((ulonglong *) at_poisson_cdf)},
{"poisson_icdf",13,9,0,*((ulonglong *) at_poisson_icdf)},
{"poisson_window",13,9,0,*((ulonglong *) at_poisson_window)},
{"polar",13,9,0,*((ulonglong *) at_polar)},
{"polar2rectangular",13,9,0,*((ulonglong *) at_polar2rectangular)},
{"polar_coordinates",13,9,0,*((ulonglong *) at_polar_coordinates)},
{"polar_point",13,9,0,*((ulonglong *) at_polar_point)},
{"polarplot",13,9,0,*((ulonglong *) at_polarplot)| 1},
{"pole",13,9,0,*((ulonglong *) at_pole)},
{"poly2symb",13,9,0,*((ulonglong *) at_poly2symb)},
{"polyEval",13,9,0,*((ulonglong *) at_polyEval)},
{"polygamma",13,9,0,*((ulonglong *) at_polygamma)},
{"polygon",13,9,0,*((ulonglong *) at_polygon)},
{"polygone_rempli",13,126,0,*((ulonglong *) at_polygone_rempli)},
{"polygonplot",13,9,0,*((ulonglong *) at_polygonplot)},
{"polygonscatterplot",13,9,0,*((ulonglong *) at_polygonscatterplot)},
{"polyhedron",13,9,0,*((ulonglong *) at_polyhedron)},
{"polynomial_regression",13,9,0,*((ulonglong *) at_polynomial_regression)},
{"polynomial_regression_plot",13,9,0,*((ulonglong *) at_polynomial_regression_plot)},
{"pop",13,9,0,*((ulonglong *) at_pop)},
{"position",13,126,0,*((ulonglong *) at_position)},
{"poslbdLMQ",13,9,0,*((ulonglong *) at_poslbdLMQ)},
{"posubLMQ",13,9,0,*((ulonglong *) at_posubLMQ)},
{"potential",13,9,0,*((ulonglong *) at_potential)| 1},
{"pour",13,56,0,*((ulonglong *) at_pour)| 1},
{"pow2exp",13,9,0,*((ulonglong *) at_pow2exp)},
{"power_regression",13,9,0,*((ulonglong *) at_power_regression)},
{"power_regression_plot",13,9,0,*((ulonglong *) at_power_regression_plot)},
{"powermod",13,9,0,*((ulonglong *) at_powermod)},
{"powerpc",13,9,0,*((ulonglong *) at_powerpc)},
{"powexpand",13,9,0,*((ulonglong *) at_powexpand)},
{"powmod",13,9,0,*((ulonglong *) at_powmod)},
{"prepend",13,9,0,*((ulonglong *) at_prepend)},
{"preval",13,9,0,*((ulonglong *) at_preval)},
{"prevperm",13,9,0,*((ulonglong *) at_prevperm)},
{"prevprime",13,9,0,*((ulonglong *) at_prevprime)},
{"primpart",13,9,0,*((ulonglong *) at_primpart)},
{"print",13,9,0,*((ulonglong *) at_print)| 1},
{"printf",13,9,0,*((ulonglong *) at_printf)},
{"printpow",13,9,0,*((ulonglong *) at_printpow)},
{"prism",13,9,0,*((ulonglong *) at_prism)},
{"product",13,9,0,*((ulonglong *) at_product)| 1},
{"prog_eval_level",13,9,0,*((ulonglong *) at_prog_eval_level)},
{"projection",13,9,0,*((ulonglong *) at_projection)},
{"proot",13,9,0,*((ulonglong *) at_proot)},
{"propFrac",13,9,0,*((ulonglong *) at_propFrac)},
{"propfrac",13,9,0,*((ulonglong *) at_propfrac)},
{"psrgcd",13,9,0,*((ulonglong *) at_psrgcd)},
{"ptayl",13,9,0,*((ulonglong *) at_ptayl)},
{"pwd",13,9,0,*((ulonglong *) at_pwd)},
{"pyramid",13,9,0,*((ulonglong *) at_pyramid)},
{"python",13,9,0,*((ulonglong *) at_python)| 1},
{"python_compat",13,9,0,*((ulonglong *) at_python_compat)},
{"python_list",13,9,0,*((ulonglong *) at_python_list)},
{"q2a",13,9,0,*((ulonglong *) at_q2a)},
{"qr",13,9,0,*((ulonglong *) at_qr)},
{"quadric",13,9,0,*((ulonglong *) at_quadric)},
{"quadrilateral",13,9,0,*((ulonglong *) at_quadrilateral)},
{"quantile",13,9,0,*((ulonglong *) at_quantile)},
{"quartile1",13,9,0,*((ulonglong *) at_quartile1)},
{"quartile3",13,9,0,*((ulonglong *) at_quartile3)},
{"quartiles",13,9,0,*((ulonglong *) at_quartiles)},
{"quaternion",13,9,0,*((ulonglong *) at_quaternion)},
{"quest",13,9,0,*((ulonglong *) at_quest)},
{"quo",13,9,0,*((ulonglong *) at_quo)},
{"quorem",13,9,0,*((ulonglong *) at_quorem)},
{"quote",13,9,0,*((ulonglong *) at_quote)| 1},
{"r2e",13,9,0,*((ulonglong *) at_r2e)},
{"radical_axis",13,9,0,*((ulonglong *) at_radical_axis)},
{"radius",13,9,0,*((ulonglong *) at_radius)},
{"ramene",13,126,0,*((ulonglong *) at_ramene)},
{"rand",13,9,0,*((ulonglong *) at_rand)},
{"randMat",13,9,0,*((ulonglong *) at_randMat)},
{"randNorm",13,9,0,*((ulonglong *) at_randNorm)},
{"randPoly",13,9,0,*((ulonglong *) at_randPoly)},
{"randbinomial",13,9,0,*((ulonglong *) at_randbinomial)},
{"randchisquare",13,9,0,*((ulonglong *) at_randchisquare)},
{"randchisquared",13,9,0,*((ulonglong *) at_randchisquared)},
{"randexp",13,9,0,*((ulonglong *) at_randexp)},
{"randfisher",13,9,0,*((ulonglong *) at_randfisher)},
{"randfisherd",13,9,0,*((ulonglong *) at_randfisherd)},
{"randgeometric",13,9,0,*((ulonglong *) at_randgeometric)},
{"randint",13,9,0,*((ulonglong *) at_randint)},
{"randmarkov",13,9,0,*((ulonglong *) at_randmarkov)},
{"randmatrix",13,9,0,*((ulonglong *) at_randmatrix)},
{"randmultinomial",13,9,0,*((ulonglong *) at_randmultinomial)},
{"randnormald",13,9,0,*((ulonglong *) at_randnormald)},
{"random",13,9,0,*((ulonglong *) at_random)},
{"randperm",13,9,0,*((ulonglong *) at_randperm)},
{"randpoisson",13,9,0,*((ulonglong *) at_randpoisson)},
{"randpoly",13,9,0,*((ulonglong *) at_randpoly)},
{"randrange",13,9,0,*((ulonglong *) at_randrange)},
{"randstudent",13,9,0,*((ulonglong *) at_randstudent)},
{"randstudentd",13,9,0,*((ulonglong *) at_randstudentd)},
{"randvector",13,9,0,*((ulonglong *) at_randvector)},
{"range",13,9,0,*((ulonglong *) at_range)},
{"rank",13,9,0,*((ulonglong *) at_rank)},
{"ranm",13,9,0,*((ulonglong *) at_ranm)},
{"ranv",13,9,0,*((ulonglong *) at_ranv)},
{"rassembler_trigo",13,9,0,*((ulonglong *) at_rassembler_trigo)},
{"rat_jordan",13,9,0,*((ulonglong *) at_rat_jordan)},
{"rat_jordan_block",13,9,0,*((ulonglong *) at_rat_jordan_block)},
{"rationalroot",13,9,0,*((ulonglong *) at_rationalroot)},
{"ratnormal",13,9,0,*((ulonglong *) at_ratnormal)},
{"rdiv",13,9,0,*((ulonglong *) at_rdiv)},
{"re",13,9,0,*((ulonglong *) at_re)},
{"read",13,77,0,*((ulonglong *) at_read)},
{"readrgb",13,9,0,*((ulonglong *) at_readrgb)},
{"readwav",13,9,0,*((ulonglong *) at_readwav)},
{"real",13,9,0,*((ulonglong *) at_real)},
{"realproot",13,9,0,*((ulonglong *) at_realproot)},
{"realroot",13,9,0,*((ulonglong *) at_realroot)},
{"reciprocation",13,9,0,*((ulonglong *) at_reciprocation)},
{"rectangle",13,9,0,*((ulonglong *) at_rectangle)| 1},
{"rectangle_plein",13,126,0,*((ulonglong *) at_rectangle_plein)},
{"rectangular2polar",13,9,0,*((ulonglong *) at_rectangular2polar)},
{"rectangular2spherical",13,9,0,*((ulonglong *) at_rectangular2spherical)},
{"rectangular_coordinates",13,9,0,*((ulonglong *) at_rectangular_coordinates)},
{"recule",13,126,0,*((ulonglong *) at_recule)},
{"red",13,2,0,*((ulonglong *) at_red)},
{"redim",13,9,0,*((ulonglong *) at_redim)| 1},
{"reduced_conic",13,9,0,*((ulonglong *) at_reduced_conic)},
{"reduced_quadric",13,9,0,*((ulonglong *) at_reduced_quadric)},
{"ref",13,9,0,*((ulonglong *) at_ref)},
{"reflection",13,9,0,*((ulonglong *) at_reflection)},
{"regroup",13,9,0,*((ulonglong *) at_regroup)},
{"rem",13,9,0,*((ulonglong *) at_rem)},
{"remain",13,9,0,*((ulonglong *) at_remain)},
{"remove",13,9,0,*((ulonglong *) at_remove)},
{"remove_language",13,9,0,*((ulonglong *) at_remove_language)},
{"reorder",13,9,0,*((ulonglong *) at_reorder)},
{"repete",13,77,0,*((ulonglong *) at_repete)| 1},
{"replace",13,9,0,*((ulonglong *) at_replace)| 1},
{"reset_solve_counter",13,9,0,*((ulonglong *) at_reset_solve_counter)},
{"residue",13,9,0,*((ulonglong *) at_residue)},
{"resoudre",13,9,0,*((ulonglong *) at_resoudre)| 1},
{"resoudre_dans_C",13,9,0,*((ulonglong *) at_resoudre_dans_C)| 1},
{"resoudre_systeme_lineaire",13,9,0,*((ulonglong *) at_resoudre_systeme_lineaire)| 1},
{"restart",13,77,0,*((ulonglong *) at_restart)},
{"restart_modes",13,77,0,*((ulonglong *) at_restart_modes)},
{"restart_vars",13,77,0,*((ulonglong *) at_restart_vars)},
{"resultant",13,9,0,*((ulonglong *) at_resultant)},
{"reverse",13,9,0,*((ulonglong *) at_reverse)},
{"reverse_rsolve",13,9,0,*((ulonglong *) at_reverse_rsolve)},
{"revert",13,9,0,*((ulonglong *) at_revert)},
{"revlist",13,9,0,*((ulonglong *) at_revlist)},
{"rhombus",13,9,0,*((ulonglong *) at_rhombus)| 1},
{"rhs",13,9,0,*((ulonglong *) at_rhs)},
{"riemann_window",13,9,0,*((ulonglong *) at_riemann_window)},
{"right",13,9,0,*((ulonglong *) at_right)},
{"right_triangle",13,9,0,*((ulonglong *) at_right_triangle)| 1},
{"risch",13,9,0,*((ulonglong *) at_risch)},
{"rm_a_z",13,9,0,*((ulonglong *) at_rm_a_z)},
{"rm_all_vars",13,9,0,*((ulonglong *) at_rm_all_vars)},
{"rmbreakpoint",13,9,0,*((ulonglong *) at_rmbreakpoint)| 1},
{"rmmod",13,9,0,*((ulonglong *) at_rmmod)},
{"rmwatch",13,9,0,*((ulonglong *) at_rmwatch)| 1},
{"romberg",13,9,0,*((ulonglong *) at_romberg)},
{"rond",13,126,0,*((ulonglong *) at_rond)},
{"rootof",13,9,0,*((ulonglong *) at_rootof)},
{"roots",13,9,0,*((ulonglong *) at_roots)},
{"rotate",13,9,0,*((ulonglong *) at_rotate)},
{"rotation",13,9,0,*((ulonglong *) at_rotation)},
{"round",13,9,0,*((ulonglong *) at_round)},
{"row",13,9,0,*((ulonglong *) at_row)},
{"rowAdd",13,9,0,*((ulonglong *) at_rowAdd)},
{"rowDim",13,9,0,*((ulonglong *) at_rowDim)},
{"rowNorm",13,9,0,*((ulonglong *) at_rowNorm)},
{"rowSwap",13,9,0,*((ulonglong *) at_rowSwap)},
{"rowdim",13,9,0,*((ulonglong *) at_rowdim)},
{"rownorm",13,9,0,*((ulonglong *) at_rownorm)},
{"rowspace",13,9,0,*((ulonglong *) at_rowspace)},
{"rowswap",13,9,0,*((ulonglong *) at_rowswap)},
{"rpn",13,9,0,*((ulonglong *) at_rpn)},
{"rref",13,9,0,*((ulonglong *) at_rref)},
{"rsolve",13,9,0,*((ulonglong *) at_rsolve)| 1},
{"sample",13,9,0,*((ulonglong *) at_sample)},
{"saute",13,126,0,*((ulonglong *) at_saute)},
{"sauve",13,126,0,*((ulonglong *) at_sauve)| 1},
{"save_history",13,9,0,*((ulonglong *) at_save_history)},
{"scalarProduct",13,9,0,*((ulonglong *) at_scalarProduct)},
{"scalar_product",13,9,0,*((ulonglong *) at_scalar_product)},
{"scale",13,9,0,*((ulonglong *) at_scale)| 1},
{"scaleadd",13,9,0,*((ulonglong *) at_scaleadd)| 1},
{"scatterplot",13,9,0,*((ulonglong *) at_scatterplot)},
{"schur",13,9,0,*((ulonglong *) at_schur)},
{"sec",13,9,0,*((ulonglong *) at_sec)},
{"sech",13,9,0,*((ulonglong *) at_sech)},
{"segment",13,9,0,*((ulonglong *) at_segment)},
{"select",13,9,0,*((ulonglong *) at_select)},
{"semi_augment",13,9,0,*((ulonglong *) at_semi_augment)},
{"seq",13,9,0,*((ulonglong *) at_seq)| 1},
{"seqplot",13,9,0,*((ulonglong *) at_seqplot)},
{"seqsolve",13,9,0,*((ulonglong *) at_seqsolve)| 1},
{"series",13,9,0,*((ulonglong *) at_series)},
{"set_language",13,9,0,*((ulonglong *) at_set_language)},
{"set_pixel",13,9,0,*((ulonglong *) at_set_pixel)},
{"shift",13,9,0,*((ulonglong *) at_shift)},
{"shift_phase",13,9,0,*((ulonglong *) at_shift_phase)},
{"show",13,9,0,*((ulonglong *) at_show)},
{"show_language",13,9,0,*((ulonglong *) at_show_language)},
{"show_pixels",13,9,0,*((ulonglong *) at_show_pixels)},
{"showturtle",13,9,0,*((ulonglong *) at_showturtle)},
{"shuffle",13,9,0,*((ulonglong *) at_shuffle)},
{"si",13,46,0,*((ulonglong *) at_si)| 1},
{"sialorssinon",13,51,0,*((ulonglong *) at_sialorssinon)| 1},
{"sign",13,9,0,*((ulonglong *) at_sign)},
{"signature",13,9,0,*((ulonglong *) at_signature)},
{"signe",13,126,0,*((ulonglong *) at_signe)},
{"similarity",13,9,0,*((ulonglong *) at_similarity)},
{"simp2",13,9,0,*((ulonglong *) at_simp2)},
{"simplex_reduce",13,9,0,*((ulonglong *) at_simplex_reduce)},
{"simplifier",13,9,0,*((ulonglong *) at_simplifier)},
{"simplify",13,9,0,*((ulonglong *) at_simplify)},
{"simult",13,9,0,*((ulonglong *) at_simult)},
{"sin",13,9,0,*((ulonglong *) at_sin)},
{"sin2costan",13,9,0,*((ulonglong *) at_sin2costan)},
{"sincos",13,9,0,*((ulonglong *) at_sincos)},
{"single_inter",13,9,0,*((ulonglong *) at_single_inter)},
{"singular",13,9,0,*((ulonglong *) at_singular)},
{"sinh",13,9,0,*((ulonglong *) at_sinh)},
{"sinon",13,50,0,*((ulonglong *) at_sinon)| 1},
{"size",13,9,0,*((ulonglong *) at_size)},
{"sizes",13,9,0,*((ulonglong *) at_sizes)},
{"skip",13,126,0,*((ulonglong *) at_skip)},
{"slope",13,9,0,*((ulonglong *) at_slope)},
{"slopeat",13,9,0,*((ulonglong *) at_slopeat)| 1},
{"slopeatraw",13,9,0,*((ulonglong *) at_slopeatraw)},
{"smith",13,9,0,*((ulonglong *) at_smith)},
{"smod",13,9,0,*((ulonglong *) at_smod)},
{"snedecor",13,9,0,*((ulonglong *) at_snedecor)},
{"snedecor_cdf",13,9,0,*((ulonglong *) at_snedecor_cdf)},
{"snedecor_icdf",13,9,0,*((ulonglong *) at_snedecor_icdf)},
{"snedecord",13,9,0,*((ulonglong *) at_snedecord)},
{"snedecord_cdf",13,9,0,*((ulonglong *) at_snedecord_cdf)},
{"snedecord_icdf",13,9,0,*((ulonglong *) at_snedecord_icdf)},
{"solve",13,9,0,*((ulonglong *) at_solve)| 1},
{"solve_zero_extremum",13,9,0,*((ulonglong *) at_solve_zero_extremum)| 1},
{"somme",13,9,0,*((ulonglong *) at_somme)| 1},
{"sommet",13,9,0,*((ulonglong *) at_sommet)},
{"sort",13,9,0,*((ulonglong *) at_sort)},
{"sorta",13,9,0,*((ulonglong *) at_sorta)},
{"sortd",13,9,0,*((ulonglong *) at_sortd)},
{"sorted",13,9,0,*((ulonglong *) at_sorted)},
{"soundsec",13,9,0,*((ulonglong *) at_soundsec)},
{"sphere",13,9,0,*((ulonglong *) at_sphere)},
{"spherical2rectangular",13,9,0,*((ulonglong *) at_spherical2rectangular)},
{"spline",13,9,0,*((ulonglong *) at_spline)},
{"split",13,9,0,*((ulonglong *) at_split)},
{"spread2mathml",13,9,0,*((ulonglong *) at_spread2mathml)},
{"spreadsheet",13,9,0,*((ulonglong *) at_spreadsheet)},
{"sq",13,9,0,*((ulonglong *) at_sq)},
{"sqrfree",13,9,0,*((ulonglong *) at_sqrfree)},
{"sqrt",13,9,0,*((ulonglong *) at_sqrt)},
{"square",13,9,0,*((ulonglong *) at_square)| 1},
{"srand",13,77,0,*((ulonglong *) at_srand)},
{"sst",13,9,0,*((ulonglong *) at_sst)| 1},
{"sst_in",13,9,0,*((ulonglong *) at_sst_in)| 1},
{"stdDev",13,9,0,*((ulonglong *) at_stdDev)},
{"stddev",13,9,0,*((ulonglong *) at_stddev)},
{"stddevp",13,9,0,*((ulonglong *) at_stddevp)},
{"step_infolevel",13,9,0,*((ulonglong *) at_step_infolevel)},
{"sto",13,9,0,*((ulonglong *) at_sto)},
{"str",13,9,0,*((ulonglong *) at_str)},
{"strassen_limit",13,9,0,*((ulonglong *) at_strassen_limit)},
{"string",13,9,0,*((ulonglong *) at_string)},
{"strip",13,9,0,*((ulonglong *) at_strip)},
{"student",13,9,0,*((ulonglong *) at_student)},
{"student_cdf",13,9,0,*((ulonglong *) at_student_cdf)},
{"student_icdf",13,9,0,*((ulonglong *) at_student_icdf)},
{"studentd",13,9,0,*((ulonglong *) at_studentd)},
{"studentd_cdf",13,9,0,*((ulonglong *) at_studentd_cdf)},
{"studentd_icdf",13,9,0,*((ulonglong *) at_studentd_icdf)},
{"studentt",13,9,0,*((ulonglong *) at_studentt)},
{"sturm",13,9,0,*((ulonglong *) at_sturm)},
{"sturmab",13,9,0,*((ulonglong *) at_sturmab)},
{"sturmseq",13,9,0,*((ulonglong *) at_sturmseq)},
{"subMat",13,9,0,*((ulonglong *) at_subMat)},
{"submatrix",13,9,0,*((ulonglong *) at_submatrix)},
{"subst",13,9,0,*((ulonglong *) at_subst)},
{"substituer",13,9,0,*((ulonglong *) at_substituer)},
{"subtype",13,9,0,*((ulonglong *) at_subtype)},
{"sum",13,9,0,*((ulonglong *) at_sum)| 1},
{"sum_riemann",13,9,0,*((ulonglong *) at_sum_riemann)},
{"suppress",13,9,0,*((ulonglong *) at_suppress)},
{"surd",13,9,0,*((ulonglong *) at_surd)},
{"svd",13,9,0,*((ulonglong *) at_svd)},
{"svg",13,9,0,*((ulonglong *) at_svg)},
{"svl",13,9,0,*((ulonglong *) at_svl)},
{"swapcol",13,9,0,*((ulonglong *) at_swapcol)},
{"swaprow",13,9,0,*((ulonglong *) at_swaprow)},
{"switch_axes",13,9,0,*((ulonglong *) at_switch_axes)},
{"sylvester",13,9,0,*((ulonglong *) at_sylvester)},
{"symb2poly",13,9,0,*((ulonglong *) at_symb2poly)},
{"syst2mat",13,9,0,*((ulonglong *) at_syst2mat)},
{"tCollect",13,9,0,*((ulonglong *) at_tCollect)},
{"tExpand",13,9,0,*((ulonglong *) at_tExpand)},
{"table",13,9,0,*((ulonglong *) at_table)},
{"tablefunc",13,9,0,*((ulonglong *) at_tablefunc)},
{"tableseq",13,9,0,*((ulonglong *) at_tableseq)| 1},
{"tabvar",13,9,0,*((ulonglong *) at_tabvar)},
{"tail",13,9,0,*((ulonglong *) at_tail)},
{"tan",13,9,0,*((ulonglong *) at_tan)},
{"tan2cossin2",13,9,0,*((ulonglong *) at_tan2cossin2)},
{"tan2sincos",13,9,0,*((ulonglong *) at_tan2sincos)},
{"tan2sincos2",13,9,0,*((ulonglong *) at_tan2sincos2)},
{"tangent",13,9,0,*((ulonglong *) at_tangent)},
{"tangente",13,9,0,*((ulonglong *) at_tangente)},
{"tanh",13,9,0,*((ulonglong *) at_tanh)},
{"tantque",13,62,0,*((ulonglong *) at_tantque)| 1},
{"taux_accroissement",13,9,0,*((ulonglong *) at_taux_accroissement)},
{"taylor",13,9,0,*((ulonglong *) at_taylor)},
{"tchebyshev1",13,9,0,*((ulonglong *) at_tchebyshev1)},
{"tchebyshev2",13,9,0,*((ulonglong *) at_tchebyshev2)},
{"tcoeff",13,9,0,*((ulonglong *) at_tcoeff)},
{"tcollect",13,9,0,*((ulonglong *) at_tcollect)},
{"tcollectsin",13,9,0,*((ulonglong *) at_tcollectsin)},
{"testfunc",13,9,0,*((ulonglong *) at_testfunc)},
{"tests",13,9,0,*((ulonglong *) at_tests)},
{"tetrahedron",13,9,0,*((ulonglong *) at_tetrahedron)},
{"texpand",13,9,0,*((ulonglong *) at_texpand)},
{"textinput",13,9,0,*((ulonglong *) at_textinput)| 1},
{"thiele",13,9,0,*((ulonglong *) at_thiele)},
{"threads_allowed",13,9,0,*((ulonglong *) at_threads_allowed)},
{"threshold",13,9,0,*((ulonglong *) at_threshold)},
{"throw",13,77,0,*((ulonglong *) at_throw)},
{"time",13,9,0,*((ulonglong *) at_time)| 1},
{"tlin",13,9,0,*((ulonglong *) at_tlin)},
{"total_degree",13,9,0,*((ulonglong *) at_total_degree)},
{"tourne_droite",13,126,0,*((ulonglong *) at_tourne_droite)},
{"tourne_gauche",13,126,0,*((ulonglong *) at_tourne_gauche)},
{"tpsolve",13,9,0,*((ulonglong *) at_tpsolve)},
{"trace",13,9,0,*((ulonglong *) at_trace)},
{"tran",13,9,0,*((ulonglong *) at_tran)},
{"translation",13,9,0,*((ulonglong *) at_translation)},
{"transpose",13,9,0,*((ulonglong *) at_transpose)},
{"triangle",13,9,0,*((ulonglong *) at_triangle)},
{"triangle_paper",13,9,0,*((ulonglong *) at_triangle_paper)},
{"triangle_plein",13,126,0,*((ulonglong *) at_triangle_plein)},
{"triangle_window",13,9,0,*((ulonglong *) at_triangle_window)},
{"trig2exp",13,9,0,*((ulonglong *) at_trig2exp)},
{"trigcos",13,9,0,*((ulonglong *) at_trigcos)},
{"trigexpand",13,9,0,*((ulonglong *) at_trigexpand)},
{"triginterp",13,9,0,*((ulonglong *) at_triginterp)},
{"trigsimplify",13,9,0,*((ulonglong *) at_trigsimplify)},
{"trigsin",13,9,0,*((ulonglong *) at_trigsin)},
{"trigtan",13,9,0,*((ulonglong *) at_trigtan)},
{"trn",13,9,0,*((ulonglong *) at_trn)},
{"trunc",13,9,0,*((ulonglong *) at_trunc)},
{"truncate",13,9,0,*((ulonglong *) at_truncate)},
{"tsimplify",13,9,0,*((ulonglong *) at_tsimplify)},
{"tukey_window",13,9,0,*((ulonglong *) at_tukey_window)},
{"turtle_stack",13,126,0,*((ulonglong *) at_turtle_stack)},
{"type",13,9,0,*((ulonglong *) at_type)},
{"ufactor",13,9,0,*((ulonglong *) at_ufactor)},
{"ugamma",13,9,0,*((ulonglong *) at_ugamma)},
{"unapply",13,9,0,*((ulonglong *) at_unapply)| 1},
{"unarchive",13,9,0,*((ulonglong *) at_unarchive)},
{"unarchive_ti",13,9,0,*((ulonglong *) at_unarchive_ti)},
{"uniform",13,9,0,*((ulonglong *) at_uniform)},
{"uniform_cdf",13,9,0,*((ulonglong *) at_uniform_cdf)},
{"uniform_icdf",13,9,0,*((ulonglong *) at_uniform_icdf)},
{"uniformd",13,9,0,*((ulonglong *) at_uniformd)},
{"uniformd_cdf",13,9,0,*((ulonglong *) at_uniformd_cdf)},
{"uniformd_icdf",13,9,0,*((ulonglong *) at_uniformd_icdf)},
{"unitV",13,9,0,*((ulonglong *) at_unitV)},
{"unquote",13,9,0,*((ulonglong *) at_unquote)},
{"upper",13,9,0,*((ulonglong *) at_upper)},
{"usimplify",13,9,0,*((ulonglong *) at_usimplify)},
{"valuation",13,9,0,*((ulonglong *) at_valuation)},
{"vandermonde",13,9,0,*((ulonglong *) at_vandermonde)},
{"variance",13,9,0,*((ulonglong *) at_variance)},
{"vector",13,9,0,*((ulonglong *) at_vector)},
{"vers",13,126,0,*((ulonglong *) at_vers)},
{"version",13,9,0,*((ulonglong *) at_version)},
{"vertices",13,9,0,*((ulonglong *) at_vertices)},
{"vertices_abc",13,9,0,*((ulonglong *) at_vertices_abc)},
{"vertices_abca",13,9,0,*((ulonglong *) at_vertices_abca)},
{"vpotential",13,9,0,*((ulonglong *) at_vpotential)| 1},
{"warn_equal_in_prog",13,9,0,*((ulonglong *) at_warn_equal_in_prog)},
{"watch",13,9,0,*((ulonglong *) at_watch)| 1},
{"weibull",13,9,0,*((ulonglong *) at_weibull)},
{"weibull_cdf",13,9,0,*((ulonglong *) at_weibull_cdf)},
{"weibull_icdf",13,9,0,*((ulonglong *) at_weibull_icdf)},
{"weibulld",13,9,0,*((ulonglong *) at_weibulld)},
{"weibulld_cdf",13,9,0,*((ulonglong *) at_weibulld_cdf)},
{"weibulld_icdf",13,9,0,*((ulonglong *) at_weibulld_icdf)},
{"welch_window",13,9,0,*((ulonglong *) at_welch_window)},
{"whattype",13,9,0,*((ulonglong *) at_whattype)},
{"when",13,9,0,*((ulonglong *) at_when)| 1},
{"white",13,2,0,*((ulonglong *) at_white)},
{"widget_size",13,9,0,*((ulonglong *) at_widget_size)},
{"wilcoxonp",13,9,0,*((ulonglong *) at_wilcoxonp)},
{"wilcoxons",13,9,0,*((ulonglong *) at_wilcoxons)},
{"wilcoxont",13,9,0,*((ulonglong *) at_wilcoxont)},
{"with_sqrt",13,9,0,*((ulonglong *) at_with_sqrt)},
{"write",13,9,0,*((ulonglong *) at_write)| 1},
{"writergb",13,9,0,*((ulonglong *) at_writergb)},
{"writewav",13,9,0,*((ulonglong *) at_writewav)},
{"wz_certificate",13,9,0,*((ulonglong *) at_wz_certificate)| 1},
{"xcas",13,9,0,*((ulonglong *) at_xcas)| 1},
{"xcas_mode",13,9,0,*((ulonglong *) at_xcas_mode)},
{"xyztrange",13,9,0,*((ulonglong *) at_xyztrange)},
{"yellow",13,2,0,*((ulonglong *) at_yellow)},
{"zeros",13,9,0,*((ulonglong *) at_zeros)| 1},
{"zip",13,9,0,*((ulonglong *) at_zip)},
{"ztrans",13,9,0,*((ulonglong *) at_ztrans)},
{"ΔLIST",13,-124,0,*((ulonglong *) at_DELTALIST)},
{"ΠLIST",13,-124,0,*((ulonglong *) at_PILIST)},
{"Σ",13,-124,0,*((ulonglong *) at_HPSUM)| 1},
{"ΣLIST",13,-124,0,*((ulonglong *) at_SIGMALIST)},
{"∂",13,-124,0,*((ulonglong *) at_HPDIFF)| 1},
{"∡",13,22,0,*((ulonglong *) at_polar_complex)},
{"∫",13,-124,0,*((ulonglong *) at_HPINT)| 1}
